
##############################################################################
# Description
#     This is the event handler file for generic lathe 
#     tracking the turret reference point
#
# Revisions
#
#   Date        Who   Reason
# 31-jul-1998   whb   Original
# 06-aug-1998   sat   Added SPINDLE_SET and TOOL_SET procedures
#                     Applied the changes in MOM_load_tool event
#
# $HISTORY$
#
###############################################################################
################################################################################
# EVENT HANDLER SECTION 
#   This section contains the control section for Lathe post processor. 
#   This program logic determinies the output to the post processor file.
#                 
#   The following procedures are performed in the order the events are
#   generated.
################################################################################
#The following command invokes the debugging mode.
#_______________________________________________________________________________

#source /users/x_satya/debug_tools/mom_debug.tcl
source /users/x_satya/debug_tools/mom_review.tcl

#*******Setting the debug mode ON/OFF*******

MOM_set_debug_mode ON 

#_______________________________________________________________________________
# The global variables that will be used in any one of the event handler are to 
# be defined here.  
#_______________________________________________________________________________

source /users/x_satya/post_base/ugpost_base.tcl
        set mom_sys_program_stop_code                 0
        set mom_sys_optional_stop_code                1
        set mom_sys_end_of_program_code               2
  
        set mom_sys_spindle_direction_code(CLW)       3
        set mom_sys_spindle_direction_code(CCLW)      4
        set mom_sys_spindle_direction_code(OFF)       5

        set mom_sys_tool_change_code                  6

        set mom_sys_coolant_code(MIST)                7
        set mom_sys_coolant_code(FLOOD)               8
        set mom_sys_coolant_code(TAP)                 8
        set mom_sys_coolant_code(OFF)                 9


        set mom_sys_clamp_code(ON)                    10
        set mom_sys_clamp_code(OFF)                   11
        set mom_sys_clamp_code(AXISON)                10
        set mom_sys_clamp_code(AXISOFF)               11

        set mom_sys_rapid_code                        0

        set mom_sys_linear_code                       1

        set mom_sys_circle_code(CLW)                  2
        set mom_sys_circle_code(CCLW)                 3

        set mom_sys_delay_code(REVOLUTIONS)           4
        set mom_sys_delay_code(SECONDS)               4

        set mom_sys_thread_advance_type(CONSTANT)     33
        set mom_sys_thread_advance_type(DECREASING)   34
        set mom_sys_thread_advance_type(INCREASING)   35

        set mom_sys_cutcom_code(OFF)                  40
        set mom_sys_cutcom_code(LEFT)                 41
        set mom_sys_cutcom_code(RIGHT)                42

        set mom_sys_inch_code                         70
        set mom_sys_metric_code                       71

        set mom_sys_output_code(ABSOLUTE)             90
        set mom_sys_output_code(INCREMENTAL)          91

        set mom_sys_spindle_max_rpm_code              92
        set mom_sys_absolute_pos_reset_code           92

        set mom_sys_feed_rate_mode_code(IPM)          94
        set mom_sys_feed_rate_mode_code(MMPM)         94
        set mom_sys_feed_rate_mode_code(IPR)          95
        set mom_sys_feed_rate_mode_code(MMPR)         95

        set mom_sys_spindle_mode_code(SFM)            96
        set mom_sys_spindle_mode_code(SMM)            96
        set mom_sys_spindle_mode_code(RPM)            97

#MAX AND MIN DECLARATIONS FOR DIFFERENT FEEDS

         set MAX_IPM                                999.99
         set MIN_IPM                                000.00
         set MAX_IPR                                9999.9
         set MIN_IPR                                0000.0
         set MAX_MMPM                               99999.9
         set MIN_MMPM                               00000.0
         set MAX_MMPR                               999999.9
         set MIN_MMPR                               000000.0
         set MAX_INV                                999999.99
         set MIN_INV                                000000.00

# Setting of Kinematic Variables defining the machine tool

         set kin_machine_type lathe

# Global variables definded and Initialised

set initial_move          0
set load_tool_flag        0
set output_T              0
set output_S              0
set spindle_SET           0

#_______________________________________________________________________________

proc  MOM_start_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the very begining of the program.
# It gets called before any command is read from the task file.
#_______________________________________________________________________________
         global mom_cutcom_status
         global mom_logname
         global mom_date
         global mom_part_name

         global warn_file
         global mom_sys_list_file_columns
         global warn_count
         global list_file

#********The following procedure opens the warning and listing files
         OPEN_files

#********The following procedure lists the header information in commentary data
         LIST_FILE_HEADER 

puts ""
puts "-------Started Postprocessing-------"
         MOM_output_literal "(######## TASK  : $mom_part_name ############)"
         MOM_output_literal "(# Created By   : $mom_logname)"
         MOM_output_literal "(# Creation Date: $mom_date)"
         MOM_output_literal "(############################################)"
         MOM_suppress always N
         MOM_output_literal "%"
         MOM_suppress off    N
         MOM_output_literal "G70 G90"

# Unsetting the default settings of variables
         catch {unset mom_cutcom_status}
}

proc  MOM_end_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the end of the program after all
# the paths are traversed.
#_______________________________________________________________________________
         global mom_part_name
         global mom_sys_end_of_program_code

         global warn_file
         global list_file
         global warn_count

         MOM_output_literal "M$mom_sys_end_of_program_code"
         MOM_output_literal "(###### END OF TASK: $mom_part_name #########)"

puts "--------- Finished Postprocessing ---------"
puts ""
puts ""

#*******The following procedure lists the tool list with time in commentary data
        LIST_FILE_TRAILER

#*******The following procedure closes the warning and listing files
        CLOSE_files
}

proc  MOM_start_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of each path in the task
# It gets called after all the general parameters of the path are loaded
# like the path name and the tool name.
#_______________________________________________________________________________
         global mom_path_name
         global mom_tool_name
         global initial_move
puts "Processing:- $mom_path_name....."
         set initial_move 0 

         MOM_output_literal "(----------------------------------------------------)"
         MOM_output_literal "(Start path: $mom_path_name with tool: $mom_tool_name)"
         MOM_output_literal "(----------------------------------------------------)"
         MOM_force once F
}

proc  MOM_end_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the end of a path.
#_______________________________________________________________________________
         global mom_path_name
         global mom_spindle_status
         global mom_coolant_status
         global mom_sys_spindle_direction_code

         global output_S
         global spindle_SET
         global prev_feed_rate_mode
         global load_tool_flag

         set load_tool_flag 0
         set mom_spindle_status "OFF"
         set mom_coolant_status "OFF"
         set output_S 0
         set spindle_SET 0

         MOM_do_template spindle_off
         MOM_do_template coolant_off
         if {[isset From_pos] == "y"} {
             MOM_do_template gohome
         }
         MOM_output_literal "(End Of Path $mom_path_name)"
         catch {unset prev_feed_rate_mode}
         catch {unset From_pos}
}

proc  MOM_tool_change {} {
#_______________________________________________________________________________
# This procedure is executed at any time there is a tool change.
# It gets called after the tool change data is loaded like the tool number 
# and the register numbers.
#_______________________________________________________________________________
}

proc  MOM_first_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the first operation, with a tool, in the task.
#_______________________________________________________________________________
}

proc MOM_from_move {} {
#_______________________________________________________________________________
# This procedure is executed for the FROM move. This is the point to which
# the tool will return at the end of path for GOHOME.
#_______________________________________________________________________________
        global mom_ref_pos
     global From_pos

     set From_pos(0) $mom_ref_pos(0)
     set From_pos(1) $mom_ref_pos(1)
     set From_pos(2) $mom_ref_pos(2)

     MOM_do_template from CREATE
}

proc  MOM_initial_move {} {
#_______________________________________________________________________________
# This procedure is executed for the initial move of each operation.  It 
# assumes the tool is moving from a safe position at rapid to the start of 
# the operation.
#_______________________________________________________________________________
  global mom_coolant_status 
  global mom_coolant_mode

  global initial_move
  global output_S
  global output_T
  global spindle_SET
  global load_tool_flag

  set mom_coolant_status $mom_coolant_mode
 
  MOM_force once  X Z 

  if {$load_tool_flag == 0} {
      TOOL_SET
  }
  MOM_do_template set_offset
  MOM_do_template tool_change

  MOM_force once  motion_g X Z 
  MOM_suppress once cutcom_g T

  MOM_do_template rapid_xz

  MOM_force once  coolant_m

  SPINDLE_SET
  set initial_move 1
  set output_T 0
}

proc  MOM_linear_move {} {
#_______________________________________________________________________________
# This procedure is executed for each linear move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are 
# loaded.
#_______________________________________________________________________________
         global mom_cutcom_mode
         global mom_cutcom_status
         global mom_feed_rate_mode 

      global prev_feed_rate_mode
      global output_T
      global output_S
      global initial_move
      global load_tool_flag

      if {[isset prev_feed_rate_mode] == "n"} {
          set prev_feed_rate_mode $mom_feed_rate_mode
          MOM_force once feed_g
      } elseif {$prev_feed_rate_mode != $mom_feed_rate_mode} {
          set prev_feed_rate_mode $mom_feed_rate_mode
          MOM_force once feed_g
      } else {
          MOM_suppress once feed_g
      }

      Feedrate_set

      if {$initial_move == 0} {
          MOM_force once  X Z 
              MOM_do_template set_offset

          if {$load_tool_flag == 0} {
              TOOL_SET
          }
          MOM_force once T M
              MOM_do_template tool_change

          MOM_force once  motion_g X Z 
          MOM_suppress once T
              MOM_do_template linear

          MOM_force once coolant_m

          SPINDLE_SET
          set initial_move 1
          set output_T 0
      } else {
          if {$output_T == 1} {
              MOM_force once T
          } else {
              MOM_suppress once T
          }
          SPINDLE_SET
          MOM_do_template linear
          set output_T 0
          MOM_force always T
      }
}

proc  MOM_circular_move {} {
#_______________________________________________________________________________
# This procedure is executed for each circular move. It gets called after
# the circle data are loaded (end point and center).
#_______________________________________________________________________________
  global mom_cutcom_mode
  global mom_cutcom_status
  global mom_feed_rate_mode

  global output_S
  global prev_feed_rate_mode

  if {[isset prev_feed_rate_mode] == "n"} {
      set prev_feed_rate_mode $mom_feed_rate_mode
      MOM_force once feed_g
  } elseif {$prev_feed_rate_mode != $mom_feed_rate_mode} {
      set prev_feed_rate_mode $mom_feed_rate_mode
      MOM_force once feed_g
  } else {
      MOM_suppress once feed_g
  }

  Feedrate_set
  SPINDLE_SET
  MOM_do_template circle
}

proc  MOM_rapid_move {} {
#_______________________________________________________________________________
# This procedure is executed for each rapid move. It gets called after the 
# positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________
         global mom_coolant_status
         global mom_coolant_mode

      global output_T
      global initial_move
      global load_tool_flag

         set mom_coolant_status $mom_coolant_mode

         if {$output_T == 1} {
             MOM_force once T
         } else {
             MOM_suppress once T
         }

      if {$initial_move == 0} {
          MOM_force once  X Z 
              MOM_do_template set_offset

          if {$load_tool_flag == 0} {
              TOOL_SET
          }
          MOM_force once T M
              MOM_do_template tool_change

          MOM_force once  motion_g X Z 
          MOM_suppress once cutcom_g T
              MOM_do_template rapid_xz

          MOM_force once  coolant_m

          SPINDLE_SET
          set initial_move 1
          set output_T 0
      } else {
          MOM_do_template rapid_xz
          set output_T 0
          MOM_force always T
      }
}

proc  MOM_lathe_thread {} {
#_______________________________________________________________________________
# This procedure is executed for each lathe thread cycle. The lathe threading
# parameters are set and are used later.
#_______________________________________________________________________________
}

proc MOM_lathe_thread_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of the lathe thread cycle.
#_______________________________________________________________________________
     global mom_lathe_thread_type
     global mom_lathe_thread_advance_type
     global mom_lathe_thread_lead_i
     global mom_lathe_thread_lead_k
     global mom_motion_distance
     global mom_lathe_thread_increment
     global mom_lathe_thread_value
        global thread_type
        global thread_increment
        global feed_rate_mode

     if {$mom_lathe_thread_advance_type == 1} {
         set thread_type CONSTANT
         MOM_suppress once E
     } elseif {$mom_lathe_thread_advance_type == 2} {
         set thread_type INCREASING
         MOM_force once E
     } else {
         set thread_type DECREASING
         MOM_force once E
     }

     if {$thread_type == "INCREASING" ||\
            $thread_type == "DECREASING"} {
         if {$mom_lathe_thread_type != 1} {
             set LENGTH $mom_motion_distance
             set LEAD $mom_lathe_thread_value
             set INCR $mom_lathe_thread_increment
             set E [expr abs(pow(($LEAD + ($INCR*$LENGTH)),2) - \
                             pow($LEAD,2))/2*$LENGTH]
             set thread_increment $E
         }
     }

     if {$mom_lathe_thread_lead_i == 0} {
         MOM_suppress once I
         MOM_force once K
     } elseif {$mom_lathe_thread_lead_k == 0} {
         MOM_suppress once K
         MOM_force once I
     } else {
         MOM_force once I
         MOM_force once K
     }    
     MOM_do_template thread
}

proc  MOM_load_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the LOAD/TOOL command.  All output for the LOAD
# command will take place with the initial move.
#_______________________________________________________________________________
      global mom_tool_number
      global mom_tool_adjust_register

      global load_tool_flag
         set load_tool_flag 1
      TOOL_SET
}

proc  MOM_sequence_number {} {
#_______________________________________________________________________________
# This procedure is executed for the Sequence Number command.
#_______________________________________________________________________________
         global mom_sequence_mode
         global mom_sequence_number
         global mom_sequence_increment
         global mom_sequence_frequency
         global mom_sequence_text
         if {[isset mom_sequence_mode] == "y"} {
            if {$mom_sequence_mode == "OFF"} {
               MOM_set_seq_off
            } elseif {$mom_sequence_mode == "ON"} {
               MOM_set_seq_on
            } elseif {$mom_sequence_mode == "AUTO"} {
               MOM_output_literal "SEQNO/AUTO ????"
            } else {
               MOM_output_literal "error: mom_sequence_mode unknown"
            }
         } else {
            MOM_reset_sequence $mom_sequence_number $mom_sequence_increment $mom_sequence_frequency
         }
}

proc  MOM_set_modes {} {
#_______________________________________________________________________________
# This procedure is executed for the Set Mode command.
#_______________________________________________________________________________
         global mom_output_mode
         global mom_arc_mode
         global mom_feed_rate_output_mode
         global mom_parallel_to_axis
         global mom_machine_mode
         global mom_modes_text
         global g_output_mode
# "ABSOLUTE", "INCREMENTAL"
         if {[isset mom_output_mode] == "y"} {
            if {$mom_output_mode == "ABSOLUTE"} {
                MOM_incremental OFF X Z
            } elseif {$mom_output_mode == "INCREMENTAL"} {
                MOM_incremental ON X Z
            }
         }
# "LINEAR", "CIRCULAR"
         if {[isset mom_arc_mode] == "y"} {
            if {$mom_arc_mode == "LINEAR"} {
            } elseif {$mom_arc_mode == "CIRCULAR"} {
            }
         }
# "OFF", "IPM", "IPR", "MMPM", "MMPR", "INVERSE"
         if {$mom_feed_rate_output_mode == "FPM"} {
         } elseif {$mom_feed_rate_output_mode == "FPR"} {
         } elseif {$mom_feed_rate_output_mode == "INVERSE"} {
         } elseif {$mom_feed_rate_output_mode == "OFF"} {
         }
# "ZAXIS", "WAXIS", "UAXIS"
         if {$mom_parallel_to_axis == "ZAXIS"} {
         } elseif {$mom_parallel_to_axis == "WAXIS"} {
         } elseif {$mom_parallel_to_axis == "UAXIS"} {
         }
# "MILL", "TURN", "PUNCH", "LASER", "TORCH", "WIRE"
         if {$mom_machine_mode == "MILL"} {
         } elseif {$mom_machine_mode == "TURN"} {
         } elseif {$mom_machine_mode == "PUNCH"} {
         } elseif {$mom_machine_mode == "LASER"} {
         } elseif {$mom_machine_mode == "TORCH"} {
         } elseif {$mom_machine_mode == "WIRE"} {
         }
}

proc  MOM_length_compensation {} {
#_______________________________________________________________________________
# This procedure is executed when the set adjust for length compensation is 
# activated. A new set offset register is taken with T command and is output
# with the immediate next motion commant.
#_______________________________________________________________________________

      global mom_tool_number
      global mom_length_comp_register

      global lathe_tool_number
      global output_T

      set output_T 1
      set lathe_tool_number $mom_tool_number
      set adjust_register $mom_length_comp_register

      if {$mom_tool_number <= 9} {
          set temp 0
          append temp $lathe_tool_number
          set lathe_tool_number $temp
      }

      if {$mom_length_comp_register <= 9} {
          set temp 0
          append temp $adjust_register
          set adjust_register $temp
      }
      append lathe_tool_number $adjust_register
}

proc  MOM_cutcom_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is activated.
#_______________________________________________________________________________
         global mom_cutcom_mode
         global mom_cutcom_status
         set mom_cutcom_status $mom_cutcom_mode
}

proc  MOM_cutcom_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is deactivated.
#_______________________________________________________________________________
         global mom_cutcom_mode
         global mom_cutcom_status

}

proc  MOM_spindle_rpm {} {
#_______________________________________________________________________________
# This procedure is executed when the Spindle command is activated.
#_______________________________________________________________________________
         global mom_spindle_mode
         global mom_spindle_status
         global initial_move
         global spindle_SET
         set mom_spindle_status $mom_spindle_mode

         if {$initial_move == 1} {
             MOM_do_template spindle
	 }
         set spindle_SET 1
}

proc  MOM_spindle_css {} {
#_______________________________________________________________________________
# This procedure is executed when the Spindle command is activated SFM/SMM mode.
#_______________________________________________________________________________
         global mom_spindle_status
         global mom_spindle_mode
         global initial_move
         global spindle_SET
         set mom_spindle_status $mom_spindle_mode

         if {$initial_move == 1} {
             MOM_do_template spindle_max
             MOM_do_template spindle
         }
         set spindle_SET 1
}

proc  MOM_spindle_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Spindle command is deactivated.
#_______________________________________________________________________________
  global spindle_SET

  set spindle_SET 0
}

proc  MOM_coolant_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Coolant command is activated.
#_______________________________________________________________________________
         global mom_coolant_mode
         global mom_coolant_status
         global initial_move
#...BUG: mom_coolant_mode default value is not getting set. So 
#...     setting the default value here.
         if {$mom_coolant_status == "SAME"} {
             set mom_coolant_mode FLOOD
         }

         set mom_coolant_status $mom_coolant_mode

	 if {$initial_move == 1} {
             MOM_do_template coolant_on
	 }
}

proc  MOM_coolant_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Coolant command is deactivated.
#_______________________________________________________________________________
}

proc  MOM_opstop {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional Stop command is activated.
#_______________________________________________________________________________
         global mom_sys_optional_stop_code
         MOM_output_literal "M$mom_sys_optional_stop_code"
}

proc  MOM_stop {} {
#_______________________________________________________________________________
# This procedure is executed when the Program Stop command is activated.
#_______________________________________________________________________________
         global mom_sys_program_stop_code
         MOM_output_literal "M$mom_sys_program_stop_code"
}

proc  MOM_opskip_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional skip command is activated.
#_______________________________________________________________________________

            MOM_set_line_leader always "/"
}

proc  MOM_opskip_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional skip command is activated.
#_______________________________________________________________________________

            MOM_set_line_leader off "/"
}

proc  MOM_delay {} {
#_______________________________________________________________________________
# This procedure is executed when the Delay command is activated.
#_______________________________________________________________________________
         MOM_force once dwell
         MOM_do_template delay
}

proc  MOM_auxfun {} {
#_______________________________________________________________________________
# This procedure is executed when the Auxiliary command is activated.
#_______________________________________________________________________________
         MOM_do_template auxiliary
}

proc  MOM_prefun {} {
#_______________________________________________________________________________
# This procedure is executed when the Preparatory function command is activated.
#_______________________________________________________________________________
         MOM_do_template preparatory
}

proc  MOM_text {} {
#_______________________________________________________________________________
# This procedure is executed when the Text command is activated.
#_______________________________________________________________________________
         global mom_user_defined_text

         MOM_output_literal "$mom_user_defined_text" 
}

proc  MOM_pprint {} {
#_______________________________________________________________________________
# This procedure is executed when the PPrint command is activated.
#_______________________________________________________________________________
         global mom_pprint
         global mom_operator_message

         if {$mom_operator_message == "ON"} {
            MOM_output_literal "($mom_pprint)"
         }
}

#proc  MOM_operator_message {} {
#_______________________________________________________________________________
# This procedure is executed when the Operator Message command is activated.
#_______________________________________________________________________________
#         global mom_operator_message
#         global mom_operator_message_status
         
#         if {$mom_operator_message_status == "ON"} {
#            MOM_output_literal "$mom_operator_message"
#         }
#}

#proc MOM_before_motion {} {
#}

proc MOM_msys {} {
}

proc MOM_select_head {} {
}

proc MOM_origin {} {
}
#____________________________________________________________________________
#
# This section is used for local procedures.
#____________________________________________________________________________

proc isset { v1 } {
#_______________________________________________________________________________
#
# The procedure isset is used to check if a paticular variable is set or not. 
# To this procedure the variable to be checked is passed as argument and 
# if it is set the "y" is returned and if it has not been set "n" is returned.
#_______________________________________________________________________________

         upvar $v1 v2
         if { [catch { set v2 }] == 0} { return y } else { return n }
}

proc SPINDLE_SET {} {
#____________________________________________________________________________
#
# This procedure decides whether to output Spindle realted commands into
# the output file and also checks if the Spindle is programmed in an 
# operation. If not then a warning is output.
#____________________________________________________________________________

  global mom_motion_type
  global mom_spindle_mode
  global mom_spindle_rpm
  global mom_spindle_speed
  global mom_path_name
  global mom_warning_info

  global spindle_SET
  global initial_move
  global output_S

  if {$initial_move == 0} {
      if {$spindle_SET == 0} {
          set mom_warning_info "WARNING: Spindle not set in $mom_path_name"
          MOM_catch_warning
          puts "WARNING: Spindle not programmed for $mom_path_name"
          if {[isset mom_spindle_rpm] == "y"} {
              puts "ACTION : Using previous Operation's Spindle setting"
          } else {
              puts "ACTION: ** NO SPINDLE OUTPUT **"
              return
          }
      }
      if {$mom_spindle_mode == "RPM"} {
          MOM_do_template spindle
          MOM_do_template coolant_on
      } else {
          if {$mom_motion_type == "CUT" || \
                  $mom_motion_type == "FIRSTCUT" || \
                      $mom_motion_type == "ENGAGE"} {
              set temp1 $mom_spindle_rpm
              set mom_spindle_rpm $mom_spindle_speed
              MOM_do_template spindle_max
              MOM_do_template spindle
              MOM_do_template coolant_on
              set mom_spindle_rpm $temp1
              set output_S 1
          } else {
              set temp2 $mom_spindle_mode
              set mom_spindle_mode "RPM"
              MOM_do_template spindle
              MOM_do_template coolant_on
              set mom_spindle_mode $temp2
          }
      }
  } else {
      if {$output_S == 0 && \
              $mom_spindle_mode != "RPM"} {
          if {$mom_motion_type == "CUT" || \
                  $mom_motion_type == "FIRSTCUT" || \
                      $mom_motion_type == "ENGAGE"} {
              set temp $mom_spindle_rpm
              set mom_spindle_rpm $mom_spindle_speed
              MOM_suppress once spindle_m
              MOM_do_template spindle_max
              MOM_do_template spindle
              set output_S 1
              set mom_spindle_rpm $temp
              MOM_force always spindle_m
         }
      }
  }
}

proc TOOL_SET {} {
#____________________________________________________________________________
#
# This procedure create the format of tool definition in the output.
# Such as : T0112
#____________________________________________________________________________

  global mom_tool_number
  global mom_tool_adjust_register

  global lathe_tool_number

  set lathe_tool_number $mom_tool_number
  set adjust_register $mom_tool_adjust_register

  if {$mom_tool_number <= 9} {
      set temp 0
      append temp $lathe_tool_number
      set lathe_tool_number $temp
  }

  if {$mom_tool_adjust_register <= 9} {
      set temp 0
      append temp $adjust_register
      set adjust_register $temp
  }
  append lathe_tool_number $adjust_register
}
