##############################################################################
# Description
#     This is the event handler file for generic 5 axis mill with dual tables
#     with a and b axes
#
# Revisions
#
#   Date        Who   Reason
# 31-jul-1998   whb   Original
#
# $HISTORY$
#
###############################################################################
################################################################################
# EVENT HANDLER SECTION 
#   This section contains the control section for M5ABTT post processor. 
#   This program logic determinies the output to the post processor file.
#                 
#   The following procedures are performed in the order the events are
#   generated.
################################################################################
#The following command invokes the debugging mode.
#_______________________________________________________________________________
#         source mom_debug.tcl
#********Setting the debug mode ON/OFF
         MOM_set_debug_mode OFF

#_______________________________________________________________________________
#The following command invokes the warning mode and the default settings.
#_______________________________________________________________________________
         source ugpost_base.tcl
#_______________________________________________________________________________
# Set kinematic variables for 5axis machine
#_______________________________________________________________________________

         set mom_kin_machine_resolution                 0.0001
         set mom_kin_machine_type                       5_axis_dual_table
         set mom_kin_4th_axis_plane                     YZ
         set mom_kin_4th_axis_min_incr                  0.001
         set mom_kin_4th_axis_min_limit                 -999.999
         set mom_kin_4th_axis_max_limit                 999.999
         set mom_kin_4th_axis_rotation                  standard
         set mom_kin_4th_axis_direction                 SIGN_DETERMINES_DIRECTION
         set mom_kin_4th_axis_zero                      0
         set mom_kin_4th_axis_center_offset(0)          0
         set mom_kin_4th_axis_center_offset(1)          0 
         set mom_kin_4th_axis_center_offset(2)          0
         set mom_kin_pivot_gauge_offset                 0
         set mom_kin_5th_axis_plane                     ZX
         set mom_kin_5th_axis_min_incr                  0.001
         set mom_kin_5th_axis_min_limit                 -999.999
         set mom_kin_5th_axis_max_limit                 999.999
         set mom_kin_5th_axis_rotation                  standard
         set mom_kin_5th_axis_direction                 sign_DETERMINES_DIRECTION
         set mom_kin_5th_axis_inclination_to_4th        90
         set mom_kin_5th_axis_zero                      0
         set mom_kin_5th_axis_center_offset(0)          0
         set mom_kin_5th_axis_center_offset(1)          0
         set mom_kin_5th_axis_center_offset(2)          0
         set mom_kin_linearization_tol                  0.001
         set mom_kin_linearization_flag                 T
         # T ON, F OFF
         set mom_kin_independent_head                   NONE
         set mom_kin_nurbs_output_type                  SIEMENS_POLY
         set mom_kin_output_unit                        IN
         set mom_kin_holder2_orientation                NEGX
         set mom_kin_holder2_offset_x                   -5
         set mom_kin_holder2_offset_y                   0
         set mom_kin_holder2_offset_z                   5

#_______________________________________________________________________________
#The following file consists of default values set for G & M codes
#_______________________________________________________________________________

#********M code declaration

         set mom_sys_program_stop_code              0
         set mom_sys_optional_stop_code             1
         set mom_sys_end_of_program_code            2

         set mom_sys_spindle_direction_code(CLW)    3
         set mom_sys_spindle_direction_code(CCLW)   4
         set mom_sys_spindle_direction_code(OFF)    5

         set mom_sys_tool_change_code               6

         set mom_sys_coolant_code(MIST)             7
         set mom_sys_coolant_code(FLOOD)            8
         set mom_sys_coolant_code(TAP)              8
         set mom_sys_coolant_code(OFF)              9


         set mom_sys_clamp_code(ON)                 10
         set mom_sys_clamp_code(OFF)                11
         set mom_sys_clamp_code(AXISON)             10
         set mom_sys_clamp_code(AXISOFF)            11

#********G code declaration

         set mom_sys_rapid_code                     0

         set mom_sys_linear_code                    1

         set mom_sys_circle_code(CLW)               2
         set mom_sys_circle_code(CCLW)              3

         set mom_sys_delay_code(REVOLUTIONS)        4
         set mom_sys_delay_code(SECONDS)            4

         set mom_sys_cutcom_plane_code(XY)          17
         set mom_sys_cutcom_plane_code(ZX)          18
         set mom_sys_cutcom_plane_code(YZ)          19

         set mom_sys_cutcom_code(OFF)               40
         set mom_sys_cutcom_code(LEFT)              41
         set mom_sys_cutcom_code(RIGHT)             42

         set mom_sys_inch_code                      70
         set mom_sys_metric_code                    71

         set mom_sys_cycle_breakchip_code           73
         set mom_sys_cycle_bore_no_drag_code        76

         set mom_sys_cycle_off                      80
         set mom_sys_cycle_drill_code               81
         set mom_sys_cycle_drill_dwell_code         82
         set mom_sys_cycle_drill_deep_code          83
         set mom_sys_cycle_tap_code                 84
         set mom_sys_cycle_bore_code                85
         set mom_sys_cycle_bore_drag_code           86
         set mom_sys_cycle_bore_back_code           87
         set mom_sys_cycle_bore_manual_code         88
         set mom_sys_cycle_bore_manual_dwell_code   89
         set mom_sys_cycle_bore_dwell_code          89
 
         set mom_sys_output_code(ABSOLUTE)          90
         set mom_sys_output_code(INCREMENTAL)       91

#_______________________________________________________________________________
# Global Variable Declaration
#_______________________________________________________________________________
         set mom_sys_list_file_columns              80
         set mom_sys_list_file_rows                 20
         set mom_sys_commentary_output              ON
#_______________________________________________________________________________
proc  MOM_start_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the very begining of the program.
# It gets called before any command is read from the task file.
#_______________________________________________________________________________
         global mom_part_name
         global mom_logname
         global mom_date

#********The following procedure opens the warning and listing files
         OPEN_files
#********The following procedure lists the header information in commentary data
         LIST_FILE_HEADER 

         MOM_output_literal "(######## TASK  : $mom_part_name ############)"
         MOM_output_literal "(# Created By   : $mom_logname)"
         MOM_output_literal "(# Creation Date: $mom_date)"
         MOM_output_literal "(############################################)"
         MOM_suppress always N
         MOM_output_literal "%"
         MOM_suppress off    N
         MOM_output_literal "G70 G90"
}

proc     MOM_end_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the end of the program after all
# the paths are traversed.
#_______________________________________________________________________________
         global mom_part_name

         MOM_do_template end_of_program
         MOM_output_literal "(###### END OF TASK: $mom_part_name #########)"

#********The following procedure lists the tool list with time in commentary data
         LIST_FILE_TRAILER
#********The following procedure closes the warning and listing files
         CLOSE_files
}

proc  MOM_start_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of each path in the task
# It gets called after all the general parameters of the path are loaded
# like the path name and the tool name.
#_______________________________________________________________________________
         global mom_path_name
         global mom_tool_name

         MOM_output_literal "(----------------------------------------------------)"
         MOM_output_literal "(Start path: $mom_path_name with tool: $mom_tool_name)"
         MOM_output_literal "(----------------------------------------------------)"
}

proc  MOM_end_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the end of a path.
#_______________________________________________________________________________
         global mom_path_name

         MOM_spindle_off 
         MOM_coolant_off 

         MOM_output_literal "(End Of Path $mom_path_name)"
}

proc  MOM_tool_change {} {
#_______________________________________________________________________________
# This procedure is executed at any time there is a tool change.
# It gets called after the tool change data is loaded like the tool number 
# and the register numbers.
#_______________________________________________________________________________
}

proc  MOM_first_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the first operation, with a tool, in the task.
#_______________________________________________________________________________
}

proc  MOM_initial_move {} {
#_______________________________________________________________________________
# This procedure is executed for the initial move of each operation.  It assumes 
# the tool is moving from a safe position at rapid to the start of the operation.
#_______________________________________________________________________________
        global   mom_coolant_mode
        set      mom_coolant_status $mom_coolant_mode

        MOM_force once  motion_g X Y Z 
	
        MOM_do_template return_home
	MOM_do_template tool_change
	MOM_do_template tool_preselect
        
        MOM_force once  motion_g X Y Z G
        MOM_force once  spindle_m coolant_m S T H 
	
        MOM_do_template rapid_xy
	MOM_do_template spindle_start
	MOM_do_template rapid_z

}

proc  MOM_linear_move {} {
#_______________________________________________________________________________
# This procedure is executed for each linear move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________
         global mom_cutcom_mode
         global mom_cutcom_status

         set mom_cutcom_status $mom_cutcom_mode
 
         MOM_do_template linear
}

proc  MOM_circular_move {} {
#_______________________________________________________________________________
# This procedure is executed for each circular move. It gets called after
# the circle data are loaded (end point and center).
#_______________________________________________________________________________
         global mom_pos_arc_axis
         global g_plane
         global mom_cutcom_mode

         set mom_cutcom_status $mom_cutcom_mode

         if {abs($mom_pos_arc_axis(2)) == 1.0} {
             set g_plane "17"
             MOM_suppress always K
         } elseif {abs($mom_pos_arc_axis(1)) == 1.0} {
             set g_plane "18"
             MOM_suppress always J
         } elseif {abs($mom_pos_arc_axis(0)) == 1.0} {
             set g_plane "19"
             MOM_suppress always I
         }

         MOM_do_template circle
}

proc  MOM_rapid_move {} {
#_______________________________________________________________________________
# This procedure is executed for each rapid move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________
         global mom_last_z_pos
         global mom_pos
         global mom_coolant_mode

         set mom_coolant_status $mom_coolant_mode

         if {$mom_pos(2) > $mom_last_z_pos } {
            MOM_do_template rapid_z
            MOM_do_template rapid_xy
         } else {
            MOM_do_template rapid_xy
            MOM_do_template rapid_z
         }
}

proc  MOM_before_output {} {
#_______________________________________________________________________________
# This procedure is executed just before a line is about to be output
# to the file. It loads the line into a variable MOM_o_buffer and then calls
# this procedure. When it returns from this procedure, the variable MOM_o_buffer
# is read and written to the file.
#_______________________________________________________________________________

#########The following procedure invokes the listing file with warnings.

         LIST_FILE
}

proc  Alignment {} {
#_______________________________________________________________________________
# This procedure is executed in buffering a value and then putting
# the value where it is desired.
#_______________________________________________________________________________
}

proc  Feedrate_set {} {
#_______________________________________________________________________________
# This procedure is executed when the Feedrate is set.
#_______________________________________________________________________________
}

proc  cycle_set {} {
#_______________________________________________________________________________
# This procedure is executed for each new cycle.  This will make sure all   
# non-modal addresses and Cycle parameters are output that need to be output
# at the start of a new cycle.
#_______________________________________________________________________________
         global mom_cycle_retract_mode
         global g_return

         MOM_force once motion_g X Y Z R cycle_dwell cycle_nodrag cycle_step

         if {$mom_cycle_retract_mode == "MANUAL"} {
            set g_return 99
         } elseif {$mom_cycle_retract_mode == "AUTO"} {
            set g_return 98
         } else {
            set g_return 99
         }
} 

proc  MOM_cycle_plane_change {} {
#_______________________________________________________________________________
# This procedure is executed at the end of cycle motion when there is a cycle 
# move occuring at a higher level than the previous position.
#_______________________________________________________________________________
         MOM_do_template cycle_plane_change
}

proc  MOM_cycle_off {} {
#_______________________________________________________________________________
# This procedure is executed at the end of cycle motion.
#_______________________________________________________________________________
         MOM_do_template cycle_off
}

proc  MOM_drill {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_drill_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill cycle.
#_______________________________________________________________________________
	 MOM_do_template cycle_drill
}

proc  MOM_drill_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill dwell cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_drill_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill dwell cycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_drill_dwell
}

proc  MOM_drill_counter_sink {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill cycle.
#_______________________________________________________________________________
         MOM_drill
}

proc  MOM_drill_counter_sink_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill cycle.
#_______________________________________________________________________________
	 MOM_drill_move
}

proc  MOM_drill_csink_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill dwell cycle.
#_______________________________________________________________________________
	 MOM_drill_dwell
}

proc  MOM_drill_csink_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill dwell cycle.
#_______________________________________________________________________________
       	 MOM_drill_dwell_move
}

proc  MOM_drill_deep {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a deep cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_drill_deep_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a  deep cycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_drill_deep
}

proc  MOM_drill_break_chip {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a brkchp cycle.
#_______________________________________________________________________________
       	 cycle_set
}

proc  MOM_drill_break_chip_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a  brkchp cycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_breakchip
}

proc  MOM_tap {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a tap cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_tap_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a tap cycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_tap
}

proc  MOM_bore {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore cycle.
#_______________________________________________________________________________
         MOM_do_template cycle_bore
}

proc  MOM_bore_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore dwell cycle.
#_______________________________________________________________________________
         MOM_do_template cycle_bore_dwell
}

proc  MOM_bore_drag {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore drag cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_drag_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore_drag cycle.
#_______________________________________________________________________________
         MOM_do_template cycle_bore_drag
}

proc  MOM_bore_no_drag {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore nodrag cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_no_drag_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore nodrag cycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_bore_no_drag
}

proc  MOM_bore_back {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore back cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_back_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a back bore cycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_bore_back
}

proc  MOM_bore_manual {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore manual cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_manual_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a manual bore cycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_bore_manual
}

proc  MOM_bore_manual_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore manual dwell bore cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_manual_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a manual dwell borecycle.
#_______________________________________________________________________________
       	 MOM_do_template cycle_bore_manual_dwell
}

proc  MOM_load_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the LOAD/TOOL command.  All output for the LOAD
# command will take place with the initial move.
#_______________________________________________________________________________
}

proc  MOM_sequence_number {} {
#_______________________________________________________________________________
# This procedure is executed for the Sequence Number command.
#_______________________________________________________________________________
         global mom_sequence_mode
         global mom_sequence_number
         global mom_sequence_increment
         global mom_sequence_frequency
         global mom_sequence_text
         if {[isset mom_sequence_mode] == "y"} {
            if {$mom_sequence_mode == "OFF"} {
               MOM_set_seq_off
            } elseif {$mom_sequence_mode == "ON"} {
               MOM_set_seq_on
            } elseif {$mom_sequence_mode == "AUTO"} {
               MOM_output_literal "SEQNO/AUTO "
            } else {
               MOM_output_literal "error: mom_sequence_mode unknown"
            }
         } else {
            MOM_reset_sequence $mom_sequence_number $mom_sequence_increment $mom_sequence_frequency
         }
}

proc  MOM_set_modes {} {
#_______________________________________________________________________________
# This procedure is executed for the Set Mode command.
#_______________________________________________________________________________
         global mom_output_mode
         global mom_arc_mode
         global mom_feed_rate_output_mode
         global mom_parallel_to_axis
         global mom_machine_mode
         global mom_modes_text
         global g_output_mode


# "ABSOLUTE", "INCREMENTAL"
            if {$mom_output_mode == "ABSOLUTE"} {
                set g_output_mode "G90"
                MOM_incremental OFF X Y Z
            } elseif {$mom_output_mode == "INCREMENTAL"} {
                set g_output_mode "G91"
                MOM_incremental ON X Y Z
            }
# "LINEAR", "CIRCULAR"
            if {$mom_arc_mode == "LINEAR"} {
            } elseif {$mom_arc_mode == "CIRCULAR"} {
            }
# "OFF", "IPM", "IPR", "MMPM", "MMPR", "INVERSE"
            if {$mom_feed_rate_output_mode == "FPM"} {
            } elseif {$mom_feed_rate_output_mode == "FPR"} {
            } elseif {$mom_feed_rate_output_mode == "INVERSE"} {
            } elseif {$mom_feed_rate_output_mode == "OFF"} {
            }
# "ZAXIS", "WAXIS", "UAXIS"
            if {$mom_parallel_to_axis == "ZAXIS"} {
            } elseif {$mom_parallel_to_axis == "WAXIS"} {
            } elseif {$mom_parallel_to_axis == "UAXIS"} {
            }
# "MILL", "TURN", "PUNCH", "LASER", "TORCH", "WIRE"
            if {$mom_machine_mode == "MILL"} {
            } elseif {$mom_machine_mode == "TURN"} {
            } elseif {$mom_machine_mode == "PUNCH"} {
            } elseif {$mom_machine_mode == "LASER"} {
            } elseif {$mom_machine_mode == "TORCH"} {
            } elseif {$mom_machine_mode == "WIRE"} {
            }
}

proc  MOM_cutcom_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is activated.
#_______________________________________________________________________________
}

proc  MOM_cutcom_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is deactivated.
#_______________________________________________________________________________
         MOM_do_template cutcom_off

}

proc  MOM_spindle_rpm {} {
#_______________________________________________________________________________
# This procedure is executed when the Spindle command is activated.
#_______________________________________________________________________________
}

proc  MOM_spindle_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Spindle command is deactivated.
#_______________________________________________________________________________
         MOM_do_template spindle_off
}

proc  MOM_coolant_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Coolant command is activated.
#_______________________________________________________________________________
}

proc  MOM_coolant_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Coolant command is deactivated.
#_______________________________________________________________________________
         MOM_do_template coolant_off
}

proc  MOM_opstop {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template opstop
}

proc  MOM_stop {} {
#_______________________________________________________________________________
# This procedure is executed when the Program Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template stop
}

proc  MOM_opskip_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional skip command is activated.
#_______________________________________________________________________________
         MOM_set_line_leader always "/"
}

proc  MOM_opskip_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional skip command is activated.
#_______________________________________________________________________________
         MOM_set_line_leader off "/"
}

proc  MOM_delay {} {
#_______________________________________________________________________________
# This procedure is executed when the Delay command is activated.
#_______________________________________________________________________________
         MOM_do_template delay
}

proc  MOM_auxfun {} {
#_______________________________________________________________________________
# This procedure is executed when the Auxiliary command is activated.
#_______________________________________________________________________________
         MOM_do_template auxiliary
}

proc  MOM_prefun {} {
#_______________________________________________________________________________
# This procedure is executed when the Preparatory function command is activated.
#_______________________________________________________________________________
         MOM_do_template preparatory
}

proc  MOM_length_compensation {} {
#_______________________________________________________________________________
# This procedure is executed when the Tool Length Compensation command is activated.
#_______________________________________________________________________________
}

proc  MOM_tool_preselect {} {
#_______________________________________________________________________________
# This procedure is executed when the Tool Preselect command is activated.
#_______________________________________________________________________________
}

proc  MOM_text {} {
#_______________________________________________________________________________
# This procedure is executed when the Text command is activated.
#_______________________________________________________________________________
         global   mom_user_defined_text
         MOM_output_literal "$mom_user_defined_text" 
}

################################################################################
