##############################################################################
# Description
#     This is the event handler file for generic mill-turn
#
# Revisions
#
#   Date        Who   Reason
# 31-jul-1998   MKG   Original
# $HISTORY$
#
################################################################################
# EVENT HANDLER SECTION 
#   This section contains the control section for mill3ax post processor. 
#   This program logic determinies the output to the post processor file.
#                 
#   The following procedures are performed in the order the events are
#   generated.
################################################################################
#The following command invokes the debugging mode.
#_______________________________________________________________________________
        source ./mom_debug.tcl
        MOM_set_debug_mode ON 
#_______________________________________________________________________________
#The following command invokes the warning mode and the default settings.
#_______________________________________________________________________________
#        source ./mom_base.tcl
        source ./ugpost_base.tcl
#_______________________________________________________________________________
#The following file consists of default values set for G & M codes
#_______________________________________________________________________________

#********M code declaration

         set mom_sys_program_stop_code              0
         set mom_sys_optional_stop_code             1
         set mom_sys_end_of_program_code            2

         set mom_sys_spindle_direction_code(CLW)    3
         set mom_sys_spindle_direction_code(CCLW)   4
         set mom_sys_spindle_direction_code(OFF)    5

         set mom_sys_tool_change_code               6

         set mom_sys_coolant_code(MIST)             7
         set mom_sys_coolant_code(FLOOD)            8
         set mom_sys_coolant_code(TAP)              8
         set mom_sys_coolant_code(OFF)              9


         set mom_sys_clamp_code(ON)                 10
         set mom_sys_clamp_code(OFF)                11
         set mom_sys_clamp_code(AXISON)             10
         set mom_sys_clamp_code(AXISOFF)            11

#********G code declaration

         set mom_sys_rapid_code                     0

         set mom_sys_linear_code                    1

         set mom_sys_circle_code(CLW)               2
         set mom_sys_circle_code(CCLW)              3

         set mom_sys_delay_code(REVOLUTIONS)        4
         set mom_sys_delay_code(SECONDS)            4

         set mom_sys_cutcom_plane_code(XY)          17
         set mom_sys_cutcom_plane_code(ZX)          18
         set mom_sys_cutcom_plane_code(YZ)          19

         set mom_sys_cutcom_code(OFF)               40
         set mom_sys_cutcom_code(LEFT)              41
         set mom_sys_cutcom_code(RIGHT)             42

         set mom_sys_inch_code                      70
         set mom_sys_metric_code                    71

         set mom_sys_cycle_breakchip_code           73
         set mom_sys_cycle_bore_no_drag_code        76

         set mom_sys_cycle_off                      80
         set mom_sys_cycle_drill_code               81
         set mom_sys_cycle_drill_dwell_code         82
         set mom_sys_cycle_drill_deep_code          83
         set mom_sys_cycle_tap_code                 84
         set mom_sys_cycle_bore_code                85
         set mom_sys_cycle_bore_drag_code           86
         set mom_sys_cycle_bore_back_code           87
         set mom_sys_cycle_bore_manual_code         88
         set mom_sys_cycle_bore_manual_dwell_code   89
         set mom_sys_cycle_bore_dwell_code          89
 
         set mom_sys_output_code(ABSOLUTE)          90
         set mom_sys_output_code(INCREMENTAL)       91

         set mom_sys_feedrate_code(INVERSE)         93
         set mom_sys_feedrate_code(IPM)             94
         set mom_sys_feedrate_code(MMPM)            94
         set mom_sys_feedrate_code(IPR)             95
         set mom_sys_feedrate_code(MMPR)            95

         set mom_sys_coordinate_type POLAR
         set lock_axis               OFF
         set lock_plane              XYPLAN
         set lock_value              0.0
         set rad2deg [expr 90.0 / asin(1.0)]
#_______________________________________________________________________________
# Kinematic Variable Declaration
#_______________________________________________________________________________
#         set                 CARTESIAN
#         set mom_kin_machine_type                   
#_______________________________________________________________________________
         set mom_kin_machine_resolution                 0.0001
         set mom_kin_machine_type                       5_axis_head_table
         set mom_kin_4th_axis_plane                     YZ
         set mom_kin_4th_axis_min_incr                  0.001
         set mom_kin_4th_axis_min_limit                 0
         set mom_kin_4th_axis_max_limit                 360
         set mom_kin_4th_axis_rotation                  standard
         set mom_kin_4th_axis_zero                      0
         set mom_kin_4th_axis_center_offset(0)          0
         set mom_kin_4th_axis_center_offset(1)          0
         set mom_kin_4th_axis_center_offset(2)          0
         set mom_kin_pivot_gauge_offset                 0
         set mom_kin_5th_axis_plane                     ZX
         set mom_kin_5th_axis_min_incr                  0.001
         set mom_kin_5th-axis_min_limit                 0
         set mom_kin_5th-axis_max_limit                 360
         set mom_kin_5th_axis_rotation                  standard
         set mom_kin_5th_axis_inclination_to_4th        90
         set mom_kin_5th_axis_zero                      0
         set mom_kin_5th_axis_center_offset(0)          0
         set mom_kin_5th_axis_center_offset(1)          0
         set mom_kin_5th_axis_center_offset(2)          0
         set mom_kin_linearization_tol                  0.001
         set mom_kin_linearization_flag                 T
         # T ON, F OFF
         set mom_kin_independent_head                   NONE
         set mom_kin_nurbs_output_type                  SIEMENS_POLY
         set mom_kin_output_unit                        IN

#_______________________________________________________________________________
# Global Variable Declaration
#_______________________________________________________________________________
         set mom_sys_list_file_columns              80
         set mom_sys_list_file_rows                 20
         set mom_sys_commentary_output              ON
         set previous_mode                          NULL
         set mom_event_time                         0
       
#MAX AND MIN DECLARATIONS FOR DIFFERENT FEEDS

         set mom_kin_max_fpm                        999.99 
         set mom_kin_min_fpm                        000.01
         set mom_kin_max_fpr                        9999.9
         set mom_kin_min_fpr                        0000.1
         set mom_kin_max_frn                        999999.99
         set mom_kin_min_frn                        000000.10
#_______________________________________________________________________________
proc MOM_catch_warning {} {
#_______________________________________________________________________________
         global mom_warning_info
         global warn_file
         global list_file
         global warn_count

         puts $warn_file "$mom_warning_info "
         puts $list_file "$mom_warning_info "

         incr warn_count +1
        }
#_______________________________________________________________________________
proc  MOM_start_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the very begining of the program.
# It gets called before any command is read from the task file.
#_______________________________________________________________________________
         global mom_part_name
         global mom_logname
         global mom_date r1 r2

#********The following procedure opens the warning and listing files
         OPEN_files
#********The following procedure lists the header information in commentary data
         LIST_FILE_HEADER 
         SUBSCRIPT_SETTING

#********Setting the debug mode ON/OFF

         MOM_output_literal "(######## TASK  : $mom_part_name ############)"
         MOM_output_literal "(# Created By   : $mom_logname)"
         MOM_output_literal "(# Creation Date: $mom_date)"
         MOM_output_literal "(############################################)"
         MOM_suppress always N
         MOM_output_literal "%"
         MOM_suppress off    N
         MOM_output_literal "G70 G90"
}

proc     MOM_end_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the end of the program after all
# the paths are traversed.
#_______________________________________________________________________________
         global mom_part_name

         MOM_do_template end_of_program
         MOM_output_literal "(###### END OF TASK: $mom_part_name #########)"

#********The following procedure lists the tool list with time in commentary data
         LIST_FILE_TRAILER
#********The following procedure closes the warning and listing files
         CLOSE_files
}

proc  MOM_start_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of each path in the task
# It gets called after all the general parameters of the path are loaded
# like the path name and the tool name.
#_______________________________________________________________________________
         global mom_path_name
         global mom_tool_name
         global mom_operation_type
         global operation

         MOM_output_literal "(----------------------------------------------------)"
         MOM_output_literal "(Start path: $mom_path_name with tool: $mom_tool_name)"
         MOM_output_literal "(----------------------------------------------------)"

         switch $mom_operation_type { 
          "PLANAR_MILL" -
          "POCKET_PROFILE" -
          "SURFACE_MILLING" -
          "FIX_CONTOUR" -
          "VAR_CONTOUR" -
          "GSSM" -
          "PARAMETER_LINE" -
          "ZIG_ZAG_SURFACE" -
          "ROUGH_TO_DEPTH" -
          "CAVITY_MILL" -
          "SEQ_CURVE_MILL" -
          "POINT_TO_POINT" -
          "MILL_MACHINE_CONTROL" -
          "MILL_USER" 
                    { set operation "MILL" }
          "LATHE" -
          "LATHE_ROUGH" -
          "LATHE_FINISH" -
          "LATHE_GROOVE" -
          "LATHE_THREAD" -              
          "LATHE_DRILL" -
          "LATHE_FACE" -
          "LATHE_DRIVE_CURVE" -
          "LATHE_MACHINE_CONTROL" -
          "LATHE_USER"
                    { set operation "LATHE" } 
         }  
}

proc  MOM_end_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the end of a path.
#_______________________________________________________________________________
         global mom_path_name

         MOM_spindle_off 
         MOM_coolant_off 

         MOM_output_literal "(End Of Path $mom_path_name)"
}

proc  MOM_tool_change {} {
#_______________________________________________________________________________
# This procedure is executed at any time there is a tool change.
# It gets called after the tool change data is loaded like the tool number 
# and the register numbers.
#_______________________________________________________________________________
}

proc  MOM_first_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the first operation, with a tool, in the task.
#_______________________________________________________________________________
}

proc  MOM_initial_move {} {
#_______________________________________________________________________________
# This procedure is executed for the initial move of each operation.  It assumes 
# the tool is moving from a safe position at rapid to the start of the operation.
#_______________________________________________________________________________
        global   mom_coolant_mode
        set      mom_coolant_status $mom_coolant_mode

        MOM_force once  motion_g X Y Z 

        Feedrate_set
	
        MOM_do_template return_home
	MOM_do_template tool_change
	MOM_do_template tool_preselect
        
        MOM_force once  motion_g X Y Z G
        MOM_force once  spindle_m coolant_m S T H 
	
        MOM_do_template rapid_xy
	MOM_do_template spindle_start
	MOM_do_template rapid_z

}

proc  MOM_linear_move {} {
#_______________________________________________________________________________
# This procedure is executed for each linear move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________
         global mom_cutcom_mode
         global mom_cutcom_status
         global mom_event_time
         global mom_pos
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         set mom_cutcom_status $mom_cutcom_mode
         Feedrate_set
 
         if { $operation == "MILL" } {
            if { $mom_sys_coordinate_type == "POLAR" || $lock_axis != "OFF" } {
		COORDINATE_SETTINGS
                MOM_output_literal "I am in POLAR $mom_pos(0)"
                MOM_output_literal "I am in POLAR $mom_pos(1)"
                MOM_output_literal "I am in POLAR $mom_pos(2)"
                MOM_do_template linear
            } else { 
                MOM_suppress once C
                MOM_do_template linear
                     MOM_output_literal "I am in cart $mom_pos(0)"
                     MOM_output_literal "I am in cart $mom_pos(1)"
                     MOM_output_literal "I am in cart $mom_pos(2)"
                     MOM_output_literal "I am in cart $mom_pos(3)"
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
                MOM_do_template linear    
                MOM_output_literal "I am in TURN $mom_pos(0)"
                MOM_output_literal "I am in TURN $mom_pos(1)"
                MOM_output_literal "I am in TURN $mom_pos(2)"
         } 
}

proc  MOM_circular_move {} {
#_______________________________________________________________________________
# This procedure is executed for each circular move. It gets called after
# the circle data are loaded (end point and center).
#_______________________________________________________________________________
         global mom_pos_arc_axis
         global g_plane
         global mom_cutcom_mode
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         set mom_cutcom_status $mom_cutcom_mode
         Feedrate_set

         if {abs($mom_pos_arc_axis(2)) == 1.0} {
             set g_plane "17"
             MOM_suppress always K
         } elseif {abs($mom_pos_arc_axis(1)) == 1.0} {
             set g_plane "18"
             MOM_suppress always J
         } elseif {abs($mom_pos_arc_axis(0)) == 1.0} {
             set g_plane "19"
             MOM_suppress always I
         }

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
                MOM_do_template circle
            } else { 
                MOM_suppress once C
                MOM_do_template circle
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
                MOM_do_template circle
         } 
}

proc  MOM_rapid_move {} {
#_______________________________________________________________________________
# This procedure is executed for each rapid move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________
         global mom_last_z_pos
         global mom_pos
         global mom_coolant_mode
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         set mom_coolant_status $mom_coolant_mode
         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
	       COORDINATE_SETTINGS
               if {$mom_pos(2) > $mom_last_z_pos } {
                  MOM_do_template rapid_z
                  MOM_do_template rapid_xy
               } else {
                  MOM_do_template rapid_xy
                  MOM_do_template rapid_z
               }
            } else { 
                if {$mom_pos(2) > $mom_last_z_pos } {
                   MOM_suppress always C
                   MOM_do_template rapid_z
                   MOM_do_template rapid_xy
                   MOM_suppress off C
                } else {
                   MOM_suppress always C
                   MOM_do_template rapid_xy
                   MOM_do_template rapid_z
                   MOM_suppress off C
                }
            } 
         } elseif {$operation == "LATHE" } {
                if {$mom_pos(2) > $mom_last_z_pos } {
                   MOM_suppress always Y C
                   MOM_do_template rapid_z
                   MOM_do_template rapid_xy
                   MOM_suppress off Y C
                } else {
                   MOM_suppress always Y C
                   MOM_do_template rapid_xy
                   MOM_do_template rapid_z
                   MOM_suppress off Y C
                }
         } 
}

proc  MOM_before_output {} {
#_______________________________________________________________________________
# This procedure is executed just before a line is about to be output
# to the file. It loads the line into a variable MOM_o_buffer and then calls
# this procedure. When it returns from this procedure, the variable MOM_o_buffer
# is read and written to the file.
#_______________________________________________________________________________
         global mom_event_time

#########The following procedure invokes the listing file with warnings.

         LIST_FILE
         set mom_event_time 0
}

proc  Alignment {} {
#_______________________________________________________________________________
# This procedure is executed in buffering a value and then putting
# the value where it is desired.
#_______________________________________________________________________________
}

proc  Feedrate_set {} {
#_______________________________________________________________________________
# This procedure is executed when the Feedrate is set.
#_______________________________________________________________________________
         global   feed
         global   previous_mode
         global   mom_feed_rate_output_mode
         global   mom_feed_rate
         global   mom_feed_rate_per_rev
         global   mom_feed_rate_number
         global   mom_warning_info
         global   Feed_IPM
         global   Feed_IPR
         global   Feed_MMPM
         global   Feed_MMPR
         global   Feed_INV

         switch $mom_feed_rate_output_mode {
          IPM     { 
                    MOM_force once feedrate_g
                    MOM_set_address_format F Feed_IPM
                    set feed $mom_feed_rate
                  }
          IPR     {
                    MOM_force once feedrate_g
                    MOM_set_address_format F Feed_IPR 
                    set feed $mom_feed_rate_per_rev
                  }
          MMPM    { 
                    MOM_force once feedrate_g
                    MOM_set_address_format F Feed_MMPM 
                    set feed $mom_feed_rate
                  }
          MMPR    { 
                    MOM_force once feedrate_g
                    MOM_set_address_format F Feed_MMPR 
                    set feed $mom_feed_rate_per_rev
                  }
          INVERSE { 
                    MOM_force once feedrate_g
                    MOM_set_address_format F Feed_INV
                    set feed $mom_feed_rate_number
                  }
         }
}

proc  cycle_set {} {
#_______________________________________________________________________________
# This procedure is executed for each new cycle.  This will make sure all   
# non-modal addresses and Cycle parameters are output that need to be output
# at the start of a new cycle.
#_______________________________________________________________________________
         global mom_cycle_retract_mode
         global g_return

         MOM_force once motion_g X Y Z R cycle_dwell cycle_nodrag cycle_step

         if {$mom_cycle_retract_mode == "MANUAL"} {
            set g_return 99
         } elseif {$mom_cycle_retract_mode == "AUTO"} {
            set g_return 98
         } else {
            set g_return 99
         }
} 

proc  MOM_cycle_plane_change {} {
#_______________________________________________________________________________
# This procedure is executed at the end of cycle motion when there is a cycle 
# move occuring at a higher level than the previous position.
#_______________________________________________________________________________
         MOM_do_template cycle_plane_change
}

proc  MOM_cycle_off {} {
#_______________________________________________________________________________
# This procedure is executed at the end of cycle motion.
#_______________________________________________________________________________
         MOM_do_template cycle_off
}

proc  MOM_drill {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_drill_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
	        MOM_do_template cycle_drill
            } else { 
                MOM_suppress once C
	        MOM_do_template cycle_drill
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
                MOM_do_template cycle_drill
         } 
}

proc  MOM_drill_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill dwell cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_drill_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill dwell cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_do_template cycle_drill_dwell
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_drill_dwell
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_drill_dwell
         } 
}

proc  MOM_drill_counter_sink {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill cycle.
#_______________________________________________________________________________
         MOM_drill
}

proc  MOM_drill_counter_sink_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
	        MOM_drill_move
            } else { 
                MOM_suppress once C
	        MOM_drill_move
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
	        MOM_drill_move
         } 
}

proc  MOM_drill_csink_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a drill dwell cycle.
#_______________________________________________________________________________
	 MOM_drill_dwell
}

proc  MOM_drill_csink_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a drill dwell cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_drill_dwell_move
            } else { 
                MOM_suppress once C
       	        MOM_drill_dwell_move
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_drill_dwell_move
         } 
}

proc  MOM_drill_deep {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a deep cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_drill_deep_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a  deep cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_do_template cycle_drill_deep
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_drill_deep
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_drill_deep
         } 
}

proc  MOM_drill_break_chip {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a brkchp cycle.
#_______________________________________________________________________________
       	 cycle_set
}

proc  MOM_drill_break_chip_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a  brkchp cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_do_template cycle_breakchip
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_breakchip
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_breakchip
         } 
}

proc  MOM_tap {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a tap cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_tap_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a tap cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_do_template cycle_tap
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_tap
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_tap
         } 
}

proc  MOM_bore {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
                MOM_do_template cycle_bore
            } else { 
                MOM_suppress once C
                MOM_do_template cycle_bore
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
                MOM_do_template cycle_bore
         } 
}

proc  MOM_bore_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore dwell cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
                MOM_do_template cycle_bore_dwell
            } else { 
                MOM_suppress once C
                MOM_do_template cycle_bore_dwell
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
                MOM_do_template cycle_bore_dwell
         } 
}

proc  MOM_bore_drag {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore drag cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_drag_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore_drag cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
                MOM_do_template cycle_bore_drag
            } else { 
                MOM_suppress once C
                MOM_do_template cycle_bore_drag
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
                MOM_do_template cycle_bore_drag
         } 
}

proc  MOM_bore_no_drag {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore nodrag cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_no_drag_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a bore nodrag cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_do_template cycle_bore_no_drag
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_bore_no_drag
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_bore_no_drag
         } 
}

proc  MOM_bore_back {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore back cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_back_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a back bore cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_do_template cycle_bore_back
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_bore_back
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_bore_back
         } 
}

proc  MOM_bore_manual {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore manual cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_manual_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a manual bore cycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	        MOM_do_template cycle_bore_manual
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_bore_manual
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_bore_manual
         } 
}

proc  MOM_bore_manual_dwell {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of a bore manual dwell bore cycle.
#_______________________________________________________________________________
	 cycle_set
}

proc  MOM_bore_manual_dwell_move {} {
#_______________________________________________________________________________
# This procedure is executed for the goto of a manual dwell borecycle.
#_______________________________________________________________________________
         global operation
	 global mom_sys_coordinate_type
	 global  r1 r2 a
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos

         Feedrate_set

         if { $operation == "MILL" } {
            if { ($mom_sys_coordinate_type == "POLAR") || ($lock_axis != 0) } {
		COORDINATE_SETTINGS
       	         MOM_do_template cycle_bore_manual_dwell
            } else { 
                MOM_suppress once C
       	        MOM_do_template cycle_bore_manual_dwell
            } 
         } elseif {$operation == "LATHE" } {
                MOM_suppress once  Y C
       	        MOM_do_template cycle_bore_manual_dwell
         } 
}

proc  MOM_load_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the LOAD/TOOL command.  All output for the LOAD
# command will take place with the initial move.
#_______________________________________________________________________________
}
proc isset { v1 } {
         upvar $v1 v2
         if { [catch { set v2 }] == 0} { return y } else { return n }
}

proc  MOM_sequence_number {} {
#_______________________________________________________________________________
# This procedure is executed for the Sequence Number command.
#_______________________________________________________________________________
         global mom_sequence_mode
         global mom_sequence_number
         global mom_sequence_increment
         global mom_sequence_frequency
         global mom_sequence_text
         if {[isset mom_sequence_mode] == "y"} {
            if {$mom_sequence_mode == "OFF"} {
               MOM_set_seq_off
            } elseif {$mom_sequence_mode == "ON"} {
               MOM_set_seq_on
            } elseif {$mom_sequence_mode == "AUTO"} {
               MOM_output_literal "SEQNO/AUTO "
            } else {
               MOM_output_literal "error: mom_sequence_mode unknown"
            }
         } else {
            MOM_reset_sequence $mom_sequence_number $mom_sequence_increment $mom_sequence_frequency
         }
}

proc  MOM_set_modes {} {
#_______________________________________________________________________________
# This procedure is executed for the Set Mode command.
#_______________________________________________________________________________
         global mom_output_mode
         global mom_arc_mode
         global mom_feed_rate_output_mode
         global mom_parallel_to_axis
         global mom_machine_mode
         global mom_modes_text
         global g_output_mode


# "ABSOLUTE", "INCREMENTAL"
            if {$mom_output_mode == "ABSOLUTE"} {
                set g_output_mode "G90"
                MOM_incremental OFF X Y Z
            } elseif {$mom_output_mode == "INCREMENTAL"} {
                set g_output_mode "G91"
                MOM_incremental ON X Y Z
            }
# "LINEAR", "CIRCULAR"
            if {$mom_arc_mode == "LINEAR"} {
            } elseif {$mom_arc_mode == "CIRCULAR"} {
            }
# "OFF", "IPM", "IPR", "MMPM", "MMPR", "INVERSE"
            if {$mom_feed_rate_output_mode == "FPM"} {
            } elseif {$mom_feed_rate_output_mode == "FPR"} {
            } elseif {$mom_feed_rate_output_mode == "INVERSE"} {
            } elseif {$mom_feed_rate_output_mode == "OFF"} {
            }
# "ZAXIS", "WAXIS", "UAXIS"
            if {$mom_parallel_to_axis == "ZAXIS"} {
            } elseif {$mom_parallel_to_axis == "WAXIS"} {
            } elseif {$mom_parallel_to_axis == "UAXIS"} {
            }
# "MILL", "TURN", "PUNCH", "LASER", "TORCH", "WIRE"
            if {$mom_machine_mode == "MILL"} {
            } elseif {$mom_machine_mode == "TURN"} {
            } elseif {$mom_machine_mode == "PUNCH"} {
            } elseif {$mom_machine_mode == "LASER"} {
            } elseif {$mom_machine_mode == "TORCH"} {
            } elseif {$mom_machine_mode == "WIRE"} {
            }
}

proc  MOM_cutcom_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is activated.
#_______________________________________________________________________________
}

proc  MOM_cutcom_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is deactivated.
#_______________________________________________________________________________
         MOM_do_template cutcom_off

}

proc  MOM_spindle_rpm {} {
#_______________________________________________________________________________
# This procedure is executed when the Spindle command is activated.
#_______________________________________________________________________________
}

proc  MOM_spindle_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Spindle command is deactivated.
#_______________________________________________________________________________
         MOM_do_template spindle_off
}

proc  MOM_coolant_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Coolant command is activated.
#_______________________________________________________________________________
}

proc  MOM_coolant_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Coolant command is deactivated.
#_______________________________________________________________________________
         MOM_do_template coolant_off
}

proc  MOM_opstop {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template opstop
}

proc  MOM_stop {} {
#_______________________________________________________________________________
# This procedure is executed when the Program Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template stop
}

proc  MOM_opskip {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional skip command is activated.
#_______________________________________________________________________________
         global mom_opskip_status

         if {$mom_opskip_status == "ON"} {
            MOM_set_line_leader always "/"
         } elseif {$mom_opskip_status == "OFF"} {
            MOM_set_line_leader off "/"
         }
}

proc  MOM_delay {} {
#_______________________________________________________________________________
# This procedure is executed when the Delay command is activated.
#_______________________________________________________________________________
         MOM_do_template delay
}

proc  MOM_auxfun {} {
#_______________________________________________________________________________
# This procedure is executed when the Auxiliary command is activated.
#_______________________________________________________________________________
         MOM_do_template auxiliary
}

proc  MOM_prefun {} {
#_______________________________________________________________________________
# This procedure is executed when the Preparatory function command is activated.
#_______________________________________________________________________________
         MOM_do_template preparatory
}

proc  MOM_length_compensation {} {
#_______________________________________________________________________________
# This procedure is executed when the Tool Length Compensation command is activated.
#_______________________________________________________________________________
}

proc  MOM_tool_preselect {} {
#_______________________________________________________________________________
# This procedure is executed when the Tool Preselect command is activated.
#_______________________________________________________________________________
}
##############################VARIABLES
set mom_sys_coordinate_type                CARTES
set lock_axis                              0
set lock_plane                             0
set lock_value                             0

proc  MOM_text {} {
#_______________________________________________________________________________
# This procedure is executed when the Text command is activated.
#_______________________________________________________________________________
         global   mom_user_defined_text
         global   mom_record_fields
         global   mom_field_count
         global   mom_sys_coordinate_type 
         global   mom_kin_machine_type  
         global   mom_kin_4th_axis_plane  
         global   mom_kin_5th_axis_plane 
         global   lock_axis
         global   lock_plane
         global   lock_value

         MOM_output_literal "$mom_user_defined_text" 
         set inx 2 
         if { $mom_record_fields(0) == "SET" } {
            if { $mom_record_fields(1) == "MODE" } {
                 switch $mom_record_fields(2) {
                    POLAR    { set mom_sys_coordinate_type POLAR }
                    CARTES   { set mom_sys_coordinate_type CARTES }
                 }
                 MOM_output_literal " IN TEXT $mom_sys_coordinate_type"
            } elseif { $mom_record_fields(1) == "LOCK" } {
               set lock_axis               OFF
               set lock_plane              OFF
               set lock_value              0.0

               while { $inx < $mom_field_count } {
                switch $mom_record_fields($inx) {
                   XAXIS    { set lock_axis               XAXIS }
                   YAXIS    { set lock_axis               YAXIS } 
                   ZAXIS    { set lock_axis               ZAXIS } 
                   AAXIS    { set lock_axis               AAXIS }
                   BAXIS    { set lock_axis               BAXIS }
                   CAXIS    { set lock_axis               CAXIS }
                   OFF      { set lock_axis               OFF }
                   XYPLAN   { set lock_plane              XYPLAN }
                   ZXPLAN   { set lock_plane              ZXPLAN }
                   YZPLAN   { set lock_plane              YZPLAN }
		   default  { set lock_value              $mom_record_fields($inx)}
                }
                incr inx
               }

               switch $mom_kin_machine_type {
                 "lathe" - 
                 "3_axis_mill" -
                 "2_axis_wedm" -      
                 "4_axis_wedm" {
                   set lock_plane OFF
                  }
               }
               
               if {$lock_plane == "OFF"} { switch $mom_kin_machine_type {
                   "4_axis_head" -
                   "4_axis_table" -
                   "5_axis_dual_table" - 
                   "5_axis_dual_head"  - 
                   "5_axis_head_table" {
                     if {$lock_axis == "XAXIS"} {
                       switch $mom_kin_4th_axis_plane {
                         "XY" { set lock_plane XYPLAN }
                         "ZX" { set lock_plane ZXPLAN }
                       }
                     } else if {$lock_axis == "YAXIS"} {
                       switch $mom_kin_4th_axis_plane {
                         "XY" { set lock_plane XYPLAN }
                         "YZ" { set lock_plane YZPLAN }
                       }
                     } else if {$lock_axis == "ZAXIS"} {
                       switch $mom_kin_4th_axis_plane {
                         "YZ" { set lock_plane YZPLAN }
                         "ZX" { set lock_plane ZXPLAN }
                       }
                     } else if {$lock_axis == "AAXIS"} {
                       set lock_plane YZPLAN
                     } else if {$lock_axis == "BAXIS"} {
                       set lock_plane ZXPLAN
                     } else if {$lock_axis == "CAXIS"} {
                       set lock_plane XYPLAN
                     }
                   }
                 }
                 if {$lock_plane == "OFF"} { switch $mom_kin_machine_type {
                   "5_axis_dual_table" - 
                   "5_axis_dual_head"  - 
                   "5_axis_head_table" {
                     if {$lock_axis == "XAXIS"} {
                       switch $mom_kin_5th_axis_plane {
                         "XY" { set lock_plane XYPLAN }
                         "ZX" { set lock_plane ZXPLAN }
                       }
                     } else if {$lock_axis == "YAXIS"} {
                       switch $mom_kin_5th_axis_plane {
                         "XY" { set lock_plane XYPLAN }
                         "YZ" { set lock_plane YZPLAN }
                       }
                     } else if {$lock_axis == "ZAXIS"} {
                       switch $mom_kin_5th_axis_plane {
                         "YZ" { set lock_plane YZPLAN }
                         "ZX" { set lock_plane ZXPLAN }
               }}}}}}

              puts " lock_axis = $lock_axis " 
              puts " lock_plane = $lock_plane " 
              puts " lock_value = $lock_value " 

              if {$lock_axis != "OFF" && $lock_plane == "OFF"} {
                MOM_output_literal "warning: $lock_axis cannot be locked with the available \
                                    rotaries ($mom_kin_machine_type)"
              error "warning: $lock_axis cannot be locked with the available \
                     rotaries ($mom_kin_machine_type)"
              }
              SUBSCRIPT_SETTING
            }
         }
}

proc SUBSCRIPT_SETTING {} {
	 global  r1  r2  index_lock_value  index_polar_radius
	 global  lock_plane
         global  lock_axis
	 global  mom_sys_coordinate_type

	 if { $mom_sys_coordinate_type == "POLAR" || $lock_axis != "OFF" } {
            puts " I am in subscript settings loop"
	    switch $lock_plane {
		   XYPLAN { set  r1  0
			    set  r2  1
                          }
		   YZPLAN { set  r1  1
			    set  r2  2
                          }
		   ZXPLAN { set  r1  2
			    set  r2  0
                          }
                   default { set  r1  0
			     set  r2  1
                           }
            }
            puts "r1 = $r1"
            puts "r2 = $r2"
         }

         if { $lock_axis  == "XAXIS"} {
            set index_lock_value 0
            switch $lock_plane {
               XYPLAN  { set index_polar_radius 1 }
               ZXPLAN  { set index_polar_radius 2 }
               default { set index_polar_radius 1 }
            }
         } elseif { $lock_axis  == "ZAXIS" } { 
            set index_lock_value 2
            switch $lock_plane {
               ZXPLAN  { set index_polar_radius 0 }
               YZPLAN  { set index_polar_radius 1 }
               default { set index_polar_radius 0 }
            }
         } else { 
            set index_lock_value 1
            switch $lock_plane {
               XYPLAN  { set index_polar_radius 0 }
               YZPLAN  { set index_polar_radius 2 }
               default { set index_polar_radius 0 }
            }
         }   
}

proc COORDINATE_SETTINGS { } {
	 global  mom_sys_coordinate_type
	 global  r1  r2  index_lock_value  index_polar_radius
         global  lock_value
         global  lock_axis
	 global  lock_plane
         global  polar_x_value
         global  polar_rotation_value
         global  mom_pos
         global  rad2deg

         set a_value $lock_value
         puts "a_value = $a_value"

         set r_value [ expr sqrt($mom_pos($r1) * $mom_pos($r1) + $mom_pos($r2) * $mom_pos($r2))]
         puts "r_value = $r_value"

         set polar_x_value  [expr sqrt($r_value * $r_value - $a_value * $a_value)]
         puts "polar_x_value = $polar_x_value"

         set mom_pos($index_lock_value) $a_value
         set mom_pos($index_polar_radius) $polar_x_value

         set mom_pos(3) \
             [expr (atan2($mom_pos($r2),$mom_pos($r1)) - atan2($a_value,$r_value)) * $rad2deg]
         puts "polar_rotation_value = $mom_pos(3)"
}

################################################################################
