###############################################################################
#
# DESCRIPTION
#
# This file contains the variables and procs that enable a simple debugger.
# If this facility is desired then this file should be 'source'd into the
# desired TCL script. 
#
# This simple debugger:
#
#     1) records the setting of each variable in the TCL interpreter by a 
#        MOM_TCL (or child) object;
#     2) records the executing of each event in the TCL interpreter by a 
#        MOM_TCL (or child) object;
#     3) creates a complete listing of (1) and (2) in a file whose name is 
#        given by mom_debug_fname_all
#     4) creates a listing of (1) and (2) for only the current event in a file
#        whose name is given by mom_debug_fname_cur and then calls a wish
#        shell to put up a dialog with that information.
#     5) allows the user to 'step' while in (4) or 'go' while in (4). If the
#        user selects 'step' then (4) is repeated for each event. If the user
#        selects 'go' then (4) is not performed again.
#
#
# REVISIONS
#
#      Date       Who       Reason
#    09may1997    fdm       Initial
#    29may1997    fdm       Allow for there to be no wish script
#    20May1998    MKG       better debugger.
#    24Jun1998    whb       do not output before_motion
#    31Jul1998    whb       do not output catch_warning
# $HISTORY$
#
################################################################################
# 
# These control where the output is written.
#
#   The complete trace
set mom_debug_fname_all "mom_debug_all.out"
#   The current event for dialog
set mom_debug_fname_cur "mom_debug_cur.out"

# This controls the name of the wish script
set mom_debug_wish_script "mom_debug_wish.tcl"

set file_all_offset1 0
set seek_flag 0
set mom_debug_file_all ""
set mom_debug_file_current ""
set mom_debug_do_wish 0
set mom_debug_done_heading 0
set mom_debug_events 1
set mom_debug_vars   1
set mom_debug_addrs  1
set mom_debug_num_flag 0
set mom_debug_range_flag 0
set mom_debug_range_lower 0
set mom_debug_range_upper 0
set mom_debug_event_num 0

set DEBUG 0

puts "mom_debug.tcl - I am being read in !"

proc MOM__debug_do_heading {} {
   global mom_part_name
   global mom_logname
   global mom_date
   global mom_debug_file_all
   global mom_debug_done_heading
 
   puts $mom_debug_file_all "Debug Output for TASK: $mom_part_name"
   puts $mom_debug_file_all "Created By:    $mom_logname"
   puts $mom_debug_file_all "Creation Date: $mom_date"
   puts $mom_debug_file_all "==============================================="

   set mom_debug_done_heading 1
}


proc MOM_before_each_event {} {
   global file_all_offset1
   global seek_flag
   global mom_debug_wish_script
   global mom_debug_file_all
   global mom_debug_file_current
   global mom_debug_fname_cur
   global mom_debug_event_name
   global mom_debug_do_wish
   global mom_debug_done_heading
   global mom_debug_events mom_debug_range_flag mom_debug_event_num 
   global mom_debug_range_lower mom_debug_range_upper mom_debug_num_flag

   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_before_each_event"
   }

   incr mom_debug_event_num

   if { $mom_debug_events == 0 } { return }
#MKG/WHB
   if { $mom_debug_event_name == "MOM_before_output" ||
        $mom_debug_event_name == "MOM_before_motion" ||
        $mom_debug_event_name == "MOM_catch_warning" } { return }

   if { $mom_debug_range_flag == 1 } {
      if { $mom_debug_event_num < $mom_debug_range_lower || \
           $mom_debug_event_num > $mom_debug_range_upper } { return }
   }

   if { $mom_debug_done_heading == 0 } { MOM__debug_do_heading }

   if { $mom_debug_num_flag == 1 } {
      set num $mom_debug_event_num
   } else {
      set num ""
   }
   set file_all_offset2 [tell $mom_debug_file_all]
   seek $mom_debug_file_all $file_all_offset1 start ; # offset file ptr
   seek $mom_debug_file_current 0 start ; # set pointer to start of file
   set seek_flag 0

   puts $mom_debug_file_all ""
   puts $mom_debug_file_all "--------------------------------------------------"
   puts $mom_debug_file_all "Event ${num}: $mom_debug_event_name"
   puts $mom_debug_file_all ""

   if { $mom_debug_do_wish } {
      puts $mom_debug_file_current ""
      puts $mom_debug_file_current "Event ${num}: $mom_debug_event_name"

      flush $mom_debug_file_current

      set mom_debug_do_wish \
      [exec wish $mom_debug_wish_script -name debug detail $mom_debug_fname_cur]
      
      close $mom_debug_file_current
      exec rm -f $mom_debug_fname_cur
      set mom_debug_file_current [open $mom_debug_fname_cur w]
   }
   seek $mom_debug_file_all $file_all_offset2 start ; # offset file ptr
}

proc MOM_before_each_add_var {} {
   global file_all_offset1
   global seek_flag
   global mom_debug_file_all
   global mom_debug_file_current
   global mom_debug_assign_var
   global mom_debug_do_wish
   global mom_debug_done_heading
   global mom_debug_vars
   global mom_debug_event_num
   global mom_debug_range_lower mom_debug_range_upper mom_debug_range_flag

   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_before_each_add_var"
   }

   if { $mom_debug_vars == 0 } { return }

   if { $mom_debug_done_heading == 0 } { MOM__debug_do_heading }

   set num $mom_debug_event_num
   incr num
   if { $mom_debug_range_flag == 1 } {
      if { $num < $mom_debug_range_lower || \
           $num > $mom_debug_range_upper } { return }
   }

   if { $seek_flag == 0 } {
      set tmp_str "                                           "
      set file_all_offset1 [tell $mom_debug_file_all]
      puts $mom_debug_file_all $tmp_str
      puts $mom_debug_file_all $tmp_str
      puts $mom_debug_file_current $tmp_str
      set seek_flag 1
   }

   puts $mom_debug_file_all "Var: $mom_debug_assign_var"
   if { $mom_debug_do_wish } {
      puts $mom_debug_file_current "Var: $mom_debug_assign_var"
   }
}


proc MOM_before_load_address {} {
   global file_all_offset1
   global seek_flag
   global mom_debug_file_all
   global mom_debug_file_current
   global mom_debug_do_wish
   global mom_debug_done_heading
   global mom_debug_load_address
   global mom_debug_addrs
   global mom_debug_event_num mom_debug_range_flag
   global mom_debug_range_lower mom_debug_range_upper 


   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_before_load_address"
   }

   if { $mom_debug_addrs == 0 } { return }

   if { $mom_debug_done_heading == 0 } { MOM__debug_do_heading }

   set num $mom_debug_event_num
   incr num
   if { $mom_debug_range_flag == 1 } {
      if { $num < $mom_debug_range_lower || \
           $num > $mom_debug_range_upper } { return }
   }

   if { $seek_flag == 0 } {
      set tmp_str "                                           "
      set file_all_offset1 [tell $mom_debug_file_all]
      puts $mom_debug_file_all $tmp_str
      puts $mom_debug_file_all $tmp_str
      puts $mom_debug_file_current $tmp_str
      set seek_flag 1
   }

   puts $mom_debug_file_all "Address: $mom_debug_load_address"
   if { $mom_debug_do_wish } {
      puts $mom_debug_file_current "Address: $mom_debug_load_address"
   }
}



proc MOM_init_debug {} {
   global mom_debug_file_all
   global mom_debug_file_current
   global mom_debug_fname_all
   global mom_debug_fname_cur
   global mom_debug_do_wish
   global mom_part_name
   global mom_logname
   global mom_date
   global mom_debug_done_heading
   global mom_debug_events mom_debug_vars mom_debug_addrs mom_debug_num_flag
   global mom_debug_range_flag mom_debug_range_lower mom_debug_range_upper
   global mom_debug_wish_script

   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_init_debug"
   }

   set mom_debug_do_wish 0
   if { [file exists $mom_debug_wish_script] } {
      set mom_debug_do_wish 1
   }

   set mom_debug_file_all [open $mom_debug_fname_all w]

   if { $mom_debug_do_wish == 1 } {
      set resp [exec wish $mom_debug_wish_script -name debug menu] 
      scan $resp "%d %d %d %d %d %d %d" mom_debug_events mom_debug_vars \
             mom_debug_addrs mom_debug_num_flag mom_debug_range_flag \
             mom_debug_range_lower mom_debug_range_upper
      set mom_debug_file_current [open $mom_debug_fname_cur w]
   } else {
      set mom_debug_events 1
      set mom_debug_vars 1
      set mom_debug_addrs 1
      set mom_debug_num_flag 1
   }

   set mom_debug_done_heading 0

   if { $DEBUG } {
      puts "mom_debug_events = $mom_debug_events"
      puts "mom_debug_vars =  $mom_debug_vars"
      puts "mom_debug_addrs = $mom_debug_addrs"
      puts "mom_debug_num_flag = $mom_debug_num_flag"
      puts "mom_debug_range_flag = $mom_debug_range_flag"
      puts "mom_debug_range_lower = $mom_debug_range_lower" 
      puts "mom_debug_range_lower = $mom_debug_range_upper"
      puts "mom_debug_do_wish = $mom_debug_do_wish"
     
   }

}


proc MOM_end_debug {} {
   global mom_debug_file_all
   global mom_debug_file_current
   global mom_debug_fname_cur
   global mom_debug_done_heading

   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_end_debug"
   }


   flush $mom_debug_file_all
   close $mom_debug_file_all
   catch { close $mom_debug_file_current }
   catch { exec rm -f $mom_debug_fname_cur }

   set mom_debug_done_heading 0
}
