#! /usr/local/bin/wish
###############################################################################
#
# DESCRIPTION
#
# This file contains the variables and procs that create an output file
# consisting of Variables, Addresses and Event names as they are set by
# UGpost. 
#
# The format of the output file is
#  A <name> = value
#  V <name> = value 
#  E <name>
#
# After this file is written to disk it will be read by a "wish" script that
# presents a dialog listing of Events. When one of these events are selected
# from the list, a window will display the settings for Variables and Addresses
# that are valid for that event
#
# If this facility is desired then this file should be 'source'd into the
# desired TCL script. 
#
# External Programs
#   debug_listbox.tcl - the wish script to display output
#
##############################################################################
# REVISIONS
#   Date       Who              Reason
#   2/11/98    mjz              Created
#   2/11/98    mjz              Added a counter for the Event to assist in file 
#                               seeks. 
#   3/25/98    HW (UG-Colonge)  add  proc_data file
#   6/10/98    Naveen (Cypress) changed debug_data file to review_data file
#   6/12/98    Naveen (Cypress) add debug_data file 
#   7/31/98    whb              remove './' to make independent
##############################################################################
# this sets the output file variable
# IT MUST BE SET THE SAME IN THE debug_listbox.tcl SCRIPT
#
set file_all_offset1 0
set seek_flag 0
set mom_debug_file_all ""
set mom_debug_done_heading 0 
set mom_debug_event_num 0
set DEBUG 0
set debug_data  "mom_debug_all.out"
set proc_data  "mom_review_proc.out"
set review_data "mom_review_all.out"
#
# This is the path to the wish script
#
set wish_script "mom_review_wish.tcl"
#
################################################################################
# proc: MOM_debug_do_heading
# 
# Description:
#               This procedure outputs the header to a file
#
################################################################################
proc MOM__debug_do_heading {} {
   global mom_part_name
   global mom_logname
   global mom_date
   global mom_debug_file_all
   global mom_debug_done_heading

   puts $mom_debug_file_all "Debug Output for TASK: $mom_part_name"
   puts $mom_debug_file_all "Created By:    $mom_logname"
   puts $mom_debug_file_all "Creation Date: $mom_date"
   puts $mom_debug_file_all "==============================================="

   set mom_debug_done_heading 1
}

################################################################################
# proc: MOM_init_debug
# 
# Description:
#   First proc called ... opens the output file
#
################################################################################
proc MOM_init_debug {} \
{
   global debug_data   ;# This controls where the output is written.
   global fileId       ;# this is the tag to write to
   global mom_logname
   global mom_date
   global num
   global mom_debug_file_all
   global mom_debug_done_heading 
   global review_data

  global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_init_debug"
   }

   set num 0

   if [ catch {open $review_data w} fileId ] \
    {
      puts stderr "error opening the file $review_data "
    } else \
    {
#     puts stdout "mom_debug_win.tcl: write $review_data"
    }

    set mom_debug_file_all [open $debug_data w]
    set mom_debug_done_heading 0

}
################################################################################
#
# proc: MOM_before_each_event
# 
# Description:
#  Output to the debug file the Event name
#
################################################################################
proc MOM_before_each_event {} {
   global fileId
   global mom_debug_event_name
   global num
   global mom_debug_file_all
   global file_all_offset1
   global seek_flag
   global mom_debug_event_num
   global mom_debug_done_heading

  global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_before_each_event"
   }

   if {$mom_debug_event_name == "MOM_before_output"} {
       puts $fileId "B $mom_debug_event_name [expr $num-1]"
   } else {
       puts $fileId "E $mom_debug_event_name $num"
       incr num
   }

   if { $mom_debug_done_heading == 0 } { MOM__debug_do_heading }

   set file_all_offset2 [tell $mom_debug_file_all]
   seek $mom_debug_file_all $file_all_offset1 start ; # offset file ptr
   set seek_flag 0

   puts $mom_debug_file_all ""
   puts $mom_debug_file_all "--------------------------------------------------"
   puts $mom_debug_file_all "Event $num: $mom_debug_event_name"
   puts $mom_debug_file_all ""

   seek $mom_debug_file_all $file_all_offset2 start ; # offset file ptr


}
################################################################################
#
# proc:  MOM_before_each_add_var
# 
# Description:
#  Gets called each time a variable is loaded
#
################################################################################
proc MOM_before_each_add_var {} {
   global fileId
   global mom_debug_assign_var
   global mom_debug_done_heading
   global mom_debug_file_all
   global seek_flag
   global file_all_offset1

   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_before_each_add_var"
   }

   if { $mom_debug_done_heading == 0 } { MOM__debug_do_heading }

   if { [regexp "mom_o_buffer" $mom_debug_assign_var] == "1" } {
        puts $fileId "O $mom_debug_assign_var"
   } else {
        puts $fileId "V $mom_debug_assign_var"
   }

   if { $seek_flag == 0 } {
      set tmp_str "                                           "
      set file_all_offset1 [tell $mom_debug_file_all]
      puts $mom_debug_file_all $tmp_str
      puts $mom_debug_file_all $tmp_str
      set seek_flag 1
   }

   puts $mom_debug_file_all "Var: $mom_debug_assign_var"


}
################################################################################
#
# proc: MOM_before_load_address
# 
# Description: 
#  Output to the debug file Address values before events are generated
#
################################################################################
proc MOM_before_load_address {} {

   global fileId
   global mom_debug_load_address
   global mom_debug_file_all
   global file_all_offset1
   global seek_flag
   global mom_debug_done_heading

   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_before_load_address"
   }

   if { $mom_debug_done_heading == 0 } { MOM__debug_do_heading }

   if { $seek_flag == 0 } {
      set tmp_str "                                           "
      set file_all_offset1 [tell $mom_debug_file_all]
      puts $mom_debug_file_all $tmp_str
      puts $mom_debug_file_all $tmp_str
      set seek_flag 1
   }

   puts $mom_debug_file_all "Address: $mom_debug_load_address"

}
################################################################################
# proc: MOM_end_debug
# 
# Function:
#  Close the output file
#
################################################################################
proc MOM_end_debug {} {
   global fileId
   global wish_script
   global debug_data
   global proc_data
   global mom_debug_file_all

   global DEBUG
   if { $DEBUG } {
      puts "Entering MOM_end_debug"
   }

#   puts stdout "mom_debug_win.tcl: close $debug_data"
   flush $fileId
   close $fileId
   flush $mom_debug_file_all
   close $mom_debug_file_all


   if [ catch {open $proc_data w} fileId2 ] \
    {
      puts stderr "error opening the file $proc_data "
    } else \
    {
#     puts stdout "mom_debug_win.tcl: write $proc_data"
     foreach WERT  [ lsort [ info procs ]] { puts $fileId2 "$WERT" }
     flush $fileId2
     close $fileId2
#     puts stdout "mom_debug_win.tcl: close $proc_data"
    }

   set mom_debug_done_heading 0

     [ exec wish $wish_script ] 
}

