#-------------------------------------------------------------------------------
# ugii_cam_feeds_speeds.tcl
#-------------------------------------------------------------------------------

proc Create_Criterion { } \
{
 global DBC_Id
 global DBC_Relop
 global DBC_Exp
 global DBC_Query

 global file
 global type
 global subtype
 global part_material
 global tool_material

 switch $DBC_Id \
    {
     FILE \
        {
         set file $DBC_Exp
        }
     TYPE \
        {
         set type $DBC_Exp
        }
     SUBTYPE \
        {
         set subtype $DBC_Exp
        }
     PART_MATERIAL \
        {
         set part_material $DBC_Exp
        }
     TOOL_MATERIAL \
        {
         set tool_material $DBC_Exp
        }
     default \
        {
        }
    }

 return
}

#-------------------------------------------------------------------------------

proc Execute_Query { } \
{
 global type
 global subtype
 global part_material
 global tool_material

 Create_Master_Array master_array master_array_size

 set match [Ask_Feeds_Speeds master_array $master_array_size \
     $type $subtype $part_material $tool_material surface_speed \
     surface_speed_units feed_per_tooth feed_per_tooth_units]

 if {$match} \
    {
     DBC_write_to_rset 0 SURFACE_SPEED        $surface_speed
     DBC_write_to_rset 0 SURFACE_SPEED_UNITS  $surface_speed_units
     DBC_write_to_rset 0 FEED_PER_TOOTH       $feed_per_tooth
     DBC_write_to_rset 0 FEED_PER_TOOTH_UNITS $feed_per_tooth_units
    }

 return
}

#-------------------------------------------------------------------------------

proc Create_Master_Array \
{
 master_array \
 master_array_size \
} \
{
 global file

 upvar $master_array      master_array_
 upvar $master_array_size master_array_size_

 set master_array_size_ 0

 if {! [string compare $file "UNDEFINED"]} return

 set file_id [open $file r]
 while {[gets $file_id line] != -1} \
    {
     if {! [string compare [string index $line 0] "#"]} continue

     if {[scan $line "%s %s %s %s %d %s %lf %s" \
          type subtype part_material tool_material surface_speed \
          surface_speed_units feed_per_tooth feed_per_tooth_units] == 8} \
        {
         set master_array_($master_array_size_,type) $type
         set master_array_($master_array_size_,subtype) $subtype
         set master_array_($master_array_size_,part_material) $part_material
         set master_array_($master_array_size_,tool_material) $tool_material
         set master_array_($master_array_size_,surface_speed) $surface_speed
         set master_array_($master_array_size_,surface_speed_units) \
             $surface_speed_units
         set master_array_($master_array_size_,feed_per_tooth) $feed_per_tooth
         set master_array_($master_array_size_,feed_per_tooth_units) \
             $feed_per_tooth_units
         incr master_array_size_
        }
    }

 close $file_id

 return
}

#-------------------------------------------------------------------------------

proc Ask_Feeds_Speeds \
{
 master_array \
 master_array_size \
 type \
 subtype \
 part_material \
 tool_material \
 surface_speed \
 surface_speed_units \
 feed_per_tooth \
 feed_per_tooth_units \
} \
{
 upvar $master_array         master_array_
 upvar $surface_speed        surface_speed_
 upvar $surface_speed_units  surface_speed_units_
 upvar $feed_per_tooth       feed_per_tooth_
 upvar $feed_per_tooth_units feed_per_tooth_units_

 set match 0

 for {set i 0} {$i < $master_array_size} {incr i} \
    {
     if {! [string compare [string toupper $type] \
           [string toupper $master_array_($i,type)]] && \
         ! [string compare [string toupper $subtype] \
           [string toupper $master_array_($i,subtype)]] && \
         ! [string compare [string toupper $part_material] \
           [string toupper $master_array_($i,part_material)]] && \
         ! [string compare [string toupper $tool_material] \
           [string toupper $master_array_($i,tool_material)]]} \
        {
         set match 1
         set surface_speed_        $master_array_($i,surface_speed)
         set surface_speed_units_  $master_array_($i,surface_speed_units)
         set feed_per_tooth_       $master_array_($i,feed_per_tooth)
         set feed_per_tooth_units_ $master_array_($i,feed_per_tooth_units)
         break
        }
    }

 return $match
}

#-------------------------------------------------------------------------------

proc Ask_Surface_Speed \
{
 master_array \
 master_array_size \
 type \
 subtype \
 part_material \
 tool_material \
 surface_speed \
 surface_speed_units \
} \
{
 upvar $master_array        master_array_
 upvar $surface_speed       surface_speed_
 upvar $surface_speed_units surface_speed_units_

 set match [Ask_Feeds_Speeds master_array_ $master_array_size \
     $type $subtype $part_material $tool_material surface_speed_ \
     surface_speed_units_ feed_per_tooth feed_per_tooth_units]

 return $match
}

#-------------------------------------------------------------------------------

proc Ask_Feed_per_Tooth \
{
 master_array \
 master_array_size \
 type \
 subtype \
 part_material \
 tool_material \
 feed_per_tooth \
 feed_per_tooth_units \
} \
{
 upvar $master_array         master_array_
 upvar $feed_per_tooth       feed_per_tooth_
 upvar $feed_per_tooth_units feed_per_tooth_units_

 set match [Ask_Feeds_Speeds master_array_ $master_array_size \
     $type $subtype $part_material $tool_material surface_speed \
     surface_speed_units feed_per_tooth_ feed_per_tooth_units_]

 return $match
}

#-------------------------------------------------------------------------------
