#-------------------------------------------------------------------------------
# ugii_cam_part_material.tcl
#-------------------------------------------------------------------------------

proc Create_Criterion { } \
{
 global DBC_Id
 global DBC_Relop
 global DBC_Exp
 global DBC_Query

 global file
 global part_material

 switch $DBC_Id \
    {
     FILE \
        {
         set file $DBC_Exp
        }
     PART_MATERIAL \
        {
         set part_material $DBC_Exp
        }
     default \
        {
        }
    }

 return
}

#-------------------------------------------------------------------------------

proc Execute_Query { } \
{
 Create_Master_Array master_array master_array_size

 Create_Part_Material_Array master_array $master_array_size \
     part_material_array part_material_array_size

 for {set i 0} {$i < $part_material_array_size} {incr i} \
    {
     DBC_write_to_rset $i PART_MATERIAL $part_material_array($i)
    }

 return
}

#-------------------------------------------------------------------------------

proc Create_Master_Array \
{
 master_array \
 master_array_size \
} \
{
 global file

 upvar $master_array      master_array_
 upvar $master_array_size master_array_size_

 set master_array_size_ 0

 if {! [string compare $file "UNDEFINED"]} return

 set file_id [open $file r]
 while {[gets $file_id line] != -1} \
    {
     if {! [string compare [string index $line 0] "#"]} continue

     if {[scan $line "%s %s %s %s %d %s %lf %s" \
          type subtype part_material tool_material surface_speed \
          surface_speed_units feed_per_tooth feed_per_tooth_units] == 8} \
        {
         set master_array_($master_array_size_,type) $type
         set master_array_($master_array_size_,subtype) $subtype
         set master_array_($master_array_size_,part_material) $part_material
         set master_array_($master_array_size_,tool_material) $tool_material
         set master_array_($master_array_size_,surface_speed) $surface_speed
         set master_array_($master_array_size_,surface_speed_units) \
             $surface_speed_units
         set master_array_($master_array_size_,feed_per_tooth) $feed_per_tooth
         set master_array_($master_array_size_,feed_per_tooth_units) \
             $feed_per_tooth_units
         incr master_array_size_
        }
    }

 close $file_id

 return
}

#-------------------------------------------------------------------------------

proc Create_Part_Material_Array \
{master_array \
 master_array_size \
 part_material_array \
 part_material_array_size} \
{
 upvar $master_array             master_array_
 upvar $part_material_array      part_material_array_
 upvar $part_material_array_size part_material_array_size_

 set part_material_array_size_ 0

 for {set i 0} {$i < $master_array_size} {incr i} \
    {
     set match 0

     for {set j 0} {$j < $part_material_array_size_} {incr j} \
        {
         if {! [string compare [string toupper $part_material_array_($j)] \
               [string toupper $master_array_($i,part_material)]]} \
            {
             set match 1
             break
            }
        }

     if {! $match} \
        {
         set part_material_array_($part_material_array_size_) \
             $master_array_($i,part_material)
         incr part_material_array_size_
        }
    }

 set part_material_list ""
 for {set i 0} {$i < $part_material_array_size_} {incr i} \
    {
     lappend part_material_list $part_material_array_($i)
    }

 set part_material_list [lsort $part_material_list]

 set i 0
 foreach part_material $part_material_list \
    {
     set part_material_array_($i) $part_material
     incr i
    }

 return
}

#-------------------------------------------------------------------------------
