##############################################################################
# Description
#     This is the event handler file for generic wire edm
#
# Revisions
#
#   Date        Who   Reason
# 08-jul-1998   whb   Original
# 31-jul-1998   whb   add opstop and stop, fix opskip
#
# $HISTORY$
#
###############################################################################
###############################################################################
# EVENT HANDLER SECTION 
#   This section contains the control section for wedm post processor. 
#   This program logic determinies the output to the post processor file.
# 
#   The following procedures are performed in the order the events are
#   generated.
###############################################################################
#______________________________________________________________________________
#The following command invokes the debugging mode.
#______________________________________________________________________________
         source mom_debug.tcl
#********Setting the debug mode ON/OFF
         MOM_set_debug_mode OFF

#______________________________________________________________________________
#The following command invokes the warning mode and the default settings.
#______________________________________________________________________________
        source ugpost_base.tcl
#_______________________________________________________________________________
# Set kinematic variables for wedm
#_______________________________________________________________________________
set mom_kin_machine_type 4_axis_wedm
set mom_kin_4th_axis_min_incr .00001
set mom_kin_5th_axis_min_incr .00001
set mom_kin_wire_tilt_output_type COORDINATES
#______________________________________________________________________________
#The following file consists of default values set for G & M codes
#______________________________________________________________________________

#********M code declaration

         set mom_sys_program_stop_code              0
         set mom_sys_optional_stop_code             1
         set mom_sys_end_of_program_code            2

         set mom_sys_spindle_direction_code(CLW)    3
         set mom_sys_spindle_direction_code(CCLW)   4
         set mom_sys_spindle_direction_code(OFF)    5

#********G code declaration

         set mom_sys_rapid_code                     0

         set mom_sys_linear_code                    1

         set mom_sys_circle_code(CLW)               2
         set mom_sys_circle_code(CCLW)              3

         set mom_sys_delay_code(REVOLUTIONS)        4
         set mom_sys_delay_code(SECONDS)            4

         set mom_sys_cutcom_code(OFF)               40
         set mom_sys_cutcom_code(LEFT)              41
         set mom_sys_cutcom_code(RIGHT)             42

         set mom_sys_inch_code                      70
         set mom_sys_metric_code                    71

         set mom_sys_output_code(ABSOLUTE)          90
         set mom_sys_output_code(INCREMENTAL)       91

#_______________________________________________________________________________
# Global Variable Declaration
#_______________________________________________________________________________
         set mom_sys_list_file_columns              132
         set mom_sys_list_file_rows                 50
         set mom_sys_commentary_output              ON
#         set mom_sys_list_output                    OFF
         set initial_move                           0
#_______________________________________________________________________________
proc  MOM_start_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the very begining of the program.
# It gets called before any command is read from the task file.
#_______________________________________________________________________________
         global mom_part_name
         global mom_logname
         global mom_date

#********The following procedure opens the warning and listing files
         OPEN_files
#********The following procedure lists the header information in commentary data
         LIST_FILE_HEADER 

         MOM_output_literal "(######## TASK  : $mom_part_name ############)"
         MOM_output_literal "(# Created By   : $mom_logname)"
         MOM_output_literal "(# Creation Date: $mom_date)"
         MOM_output_literal "(############################################)"
         MOM_suppress always N
         MOM_output_literal "%"
         MOM_suppress off    N
         MOM_output_literal "G70 G90"
}

proc     MOM_end_of_program {} {
#_______________________________________________________________________________
# This procedure is executed at the end of the program after all
# the paths are traversed.
#_______________________________________________________________________________
         global mom_part_name

         MOM_do_template End_of_program
         MOM_output_literal "(###### END OF TASK: $mom_part_name #########)"

#********The following procedure lists the tool list with time in commentary data
         LIST_FILE_TRAILER
#********The following procedure closes the warning and listing files
         CLOSE_files
}

proc  MOM_start_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the begining of each path in the task
# It gets called after all the general parameters of the path are loaded
# like the path name and the tool name.
#_______________________________________________________________________________
         global mom_path_name
         global mom_tool_name

         MOM_output_literal "(----------------------------------------------------)"
         MOM_output_literal "(Start path: $mom_path_name with tool: $mom_tool_name)"
         MOM_output_literal "(----------------------------------------------------)"
}

proc  MOM_end_of_path {} {
#_______________________________________________________________________________
# This procedure is executed at the end of a path.
#_______________________________________________________________________________
         global mom_path_name

         MOM_output_literal "(End Of Path $mom_path_name)"
}

proc  MOM_tool_change {} {
#_______________________________________________________________________________
# This procedure is executed at any time there is a tool change.
# It gets called after the tool change data is loaded like the tool number 
# and the register numbers.
#_______________________________________________________________________________
}

proc  MOM_first_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the first operation, with a tool, in the task.
#_______________________________________________________________________________
}

proc  MOM_initial_move {} {
#_______________________________________________________________________________
# This procedure is executed for the initial move of each operation.  It assumes 
# the tool is moving from a safe position at rapid to the start of the operation.
#_______________________________________________________________________________
        global initial_move

        MOM_force once motion_g X Y U V
        MOM_do_template Load_wire
        MOM_do_template linear
        set initial_move 0
}

proc  MOM_linear_move {} {
#_______________________________________________________________________________
# This procedure is executed for each linear move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________
         global initial_move
         global mom_motion_type

         if {$mom_motion_type == "FROM"} {
            MOM_do_template From CREATE
            return
         }
         if {$initial_move == 1} {
            MOM_force once motion_g X Y U V
            MOM_do_template Load_wire
            set initial_move 0
         }
         MOM_do_template linear
}

proc  MOM_circular_move {} {
#_______________________________________________________________________________
# This procedure is executed for each circular move. It gets called after
# the circle data are loaded (end point and center).
#_______________________________________________________________________________
         global initial_move

         if {$initial_move == 1} {
            MOM_force once motion_g X Y U V
            MOM_do_template Load_wire
            set initial_move 0
         }
         MOM_do_template circle
}

proc  MOM_rapid_move {} {
#_______________________________________________________________________________
# This procedure is executed for each rapid move. It gets called after
# the positioning varables, position and tool axis (X,Y,Z,TAX,TAY,TAZ) are loaded.
#_______________________________________________________________________________
         global initial_move

         if {$initial_move == 1} {
            MOM_force once motion_g X Y U V
            MOM_do_template Load_wire
            set initial_move 0
         }
         MOM_do_template rapid_xy
}

proc  MOM_before_output {} {
#_______________________________________________________________________________
# This procedure is executed just before a line is about to be output
# to the file. It loads the line into a variable MOM_o_buffer and then calls
# this procedure. When it returns from this procedure, the variable MOM_o_buffer
# is read and written to the file.
#_______________________________________________________________________________

#########The following procedure invokes the listing file with warnings.

         LIST_FILE
}


proc  MOM_load_tool {} {
#_______________________________________________________________________________
# This procedure is executed for the LOAD/TOOL command.  All output for the LOAD
# command will take place with the initial move.
#_______________________________________________________________________________
}

proc  MOM_thread_wire {} {
        global initial_move
        set initial_move 1
}

proc  MOM_cut_wire {} {
          MOM_do_template Cut_wire
}

proc  MOM_sequence_number {} {
#_______________________________________________________________________________
# This procedure is executed for the Sequence Number command.
#_______________________________________________________________________________
         global mom_sequence_mode
         global mom_sequence_number
         global mom_sequence_increment
         global mom_sequence_frequency
         global mom_sequence_text
         if {[isset mom_sequence_mode] == "y"} {
            if {$mom_sequence_mode == "OFF"} {
               MOM_set_seq_off
            } elseif {$mom_sequence_mode == "ON"} {
               MOM_set_seq_on
            } elseif {$mom_sequence_mode == "AUTO"} {
               MOM_output_literal "SEQNO/AUTO "
            } else {
               MOM_output_literal "error: mom_sequence_mode unknown"
            }
         } else {
            MOM_reset_sequence $mom_sequence_number $mom_sequence_increment $mom_sequence_frequency
         }
}

proc  MOM_cutcom_on {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is activated.
#_______________________________________________________________________________
}

proc  MOM_cutcom_off {} {
#_______________________________________________________________________________
# This procedure is executed when the Cutcom command is deactivated.
#_______________________________________________________________________________
         MOM_do_template cutcom_off

}

proc  MOM_opstop {} {
#_______________________________________________________________________________
# This procedure is executed when the Optional Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template opstop
}

proc  MOM_stop {} {
#_______________________________________________________________________________
# This procedure is executed when the Program Stop command is activated.
#_______________________________________________________________________________
         MOM_do_template stop
}

proc  MOM_opskip_on {} {MOM_set_line_leader always "/"}
proc  MOM_opskip_off {} {MOM_set_line_leader off "/"}

proc  MOM_auxfun {} {
#_______________________________________________________________________________
# This procedure is executed when the Auxiliary command is activated.
#_______________________________________________________________________________
         MOM_do_template Auxiliary
}

proc  MOM_prefun {} {
#_______________________________________________________________________________
# This procedure is executed when the Preparatory function command is activated.
#_______________________________________________________________________________
         MOM_do_template Preparatory
}

proc  MOM_text {} {
#_______________________________________________________________________________
# This procedure is executed when the Text command is activated.
#_______________________________________________________________________________
         global   mom_user_defined_text
         MOM_output_literal "$mom_user_defined_text" 
}

proc  MOM_before_motion {} {
}
################################################################################
